#===========================================================================
#  Filename: BulkExport.ksh
#    Author: Craig Schneider
# Orig Date: 05/05/15
# Copyright: ShadowScape Technologies, Inc. (see copyright file for details)
#  Synopsis: BulkExport from a database table to a file.
#===========================================================================

. $EZ_SHARED_ENV

function Usage
{
   if [ "$1" != "" ] ; then
      echo
      echo "$1"
   fi
   cat <<!

Usage: BulkExport -TableName TableName [-RecordSrc RecordSrc] 
                  [-RowLimit RowLimit] [-Quiet] [-Verbose]

     -RecordSrc: Only export records with the specified record src.
      -RowLimit: Limit the export to the specified number of rows.
         -Quiet: Suppress non critical messages about operations performed.
     -TableName: Specifies the name of the table to be exported.
       -Verbose: Display verbose messages about operations being performed.

!
   exit 1
}

EZ_DRYRUN=FALSE
QUIET_MODE=FALSE
RECORD_SRC=
ROW_LIMIT_CLAUSE=
TABLE_NAME=
VERBOSE_MODE=FALSE

typeset -l LOWERCASE_ARG
while [ "$#" -ne 0 ]
do
   LOWERCASE_ARG="$1"
   case $LOWERCASE_ARG in
      -recordsrc)
          RECORD_SRC="$2"
          shift
          shift ;;
      -rowlimit)
          ROW_LIMIT_CLAUSE="top $2"
          shift
          shift ;;
      -tablename)
          TABLE_NAME="$2"
          shift
          shift ;;
      -quiet)
          QUIET_MODE=TRUE
          shift ;;
      -verbose)
          VERBOSE_MODE=TRUE
          shift ;;
      -?) Usage
          shift ;;
      *)  if [ "$1" != "${1#-}" ] ; then
             Usage "Invalid argument $1"
          else
             if [ "$TEST_DLL_LIST" = "" ] ; then
                TEST_DLL_LIST="$1"
             else
                TEST_DLL_LIST="$TEST_DLL_LIST,$1"
             fi
          fi
          shift ;;
   esac
done

if [ "$TABLE_NAME" = "" ] ; then
   Usage "Must specify a TableName to export."
fi

BCP_EXE="C:/Program Files/Microsoft SQL Server/110/Tools/Binn/bcp.exe"

BCP_OUTPUT_FILE_NAME="$TABLE_NAME.bcp"
if [ "$RECORD_SRC" != "" ] ; then
   BCP_OUTPUT_FILE_NAME="$TABLE_NAME.$RECORD_SRC.bcp"
fi
BCP_FORMAT_FILE_NAME="$BCP_OUTPUT_FILE_NAME.fmt"

SELECT_STATEMENT="select"
if [ "$ROW_LIMIT_CLAUSE" != "" ] ; then
   SELECT_STATEMENT="$SELECT_STATEMENT $ROW_LIMIT_CLAUSE"
fi
SELECT_STATEMENT="$SELECT_STATEMENT * from $TABLE_NAME"
if [ "$RECORD_SRC" != "" ] ; then
   SELECT_STATEMENT="$SELECT_STATEMENT where RECORD_SRC = '$RECORD_SRC'"
fi

if [ "$VERBOSE_MODE" = TRUE ] ; then
   echo "$SELECT_STATEMENT"
fi

"$BCP_EXE" "$SELECT_STATEMENT" queryout "$BCP_OUTPUT_FILE_NAME" \
           -c -t ^ -U NP_DBA -P DBA1A -S PCC-DEV5 -d Dev_NP_A | \
           egrep -v 'Starting copy...|SQLState =|will convert empty strings|rows successfully bulk-copied|rows copied.|Network packet size|Clock Time' | \
           sed -e '/^$/d'
EXIT_CODE=$?
if [ "$EXIT_CODE" -ne 0 ] ; then
   exit $EXIT_CODE
fi

if [ "$QUIET_MODE" != TRUE ] ; then
   ROWS_EXPORTED=`wc -l $BCP_OUTPUT_FILE_NAME | awk '{print $1}'`
   echo "Successfully exported $ROWS_EXPORTED rows into $BCP_OUTPUT_FILE_NAME."
fi

"$BCP_EXE" "$TABLE_NAME" format nul -f "$BCP_FORMAT_FILE_NAME" \
           -c -t ^ -U NP_DBA -P DBA1A -S PCC-DEV5 -d Dev_NP_A
if [ "$QUIET_MODE" != TRUE ] ; then
   echo "Successfully created format file $BCP_FORMAT_FILE_NAME."
fi

exit $EXIT_CODE
