#===========================================================================
#  Filename: CodeCoverage.ksh
#    Author: Craig Schneider
# Orig Date: 06/09/14
# Copyright: ShadowScape Technologies, Inc. (see copyright file for details)
#  Synopsis: Generate code coverage data when running an executable.
#===========================================================================

. $EZ_SHARED_ENV

function Usage
{
   if [ "$1" != "" ] ; then
      echo
      echo "$1"
   fi
   cat <<!

Usage: CodeCoverage [-MasterFileName MasterFileName] [-Stats] [-Verbose]
                    ExecutableName [ExecutableArgs ...]

 ExecutableName: The name of the executable to generate code coverage for.
 ExecutableArgs: The command line arguments for the executable.
-MasterFileName: The master coverage file name to use.
         -Stats: Display the CodeCoverage Stats for this run.
       -Verbose: Display verbose messages about operations being performed.

!
   exit 1
}

export CODE_COVERAGE_ARG_SEPARATOR="|@|"
export CODE_COVERAGE_EXECUTABLE_NAME=
export CODE_COVERAGE_EXECUTABLE_ARGS=
OUTPUT_FILE_NAME_KSH="$TMPDIR/CodeCoverage.$$"
export CODE_COVERAGE_OUTPUT_FILE_NAME="$(Path2Win.ksh $OUTPUT_FILE_NAME_KSH)"
rm -f "$OUTPUT_FILE_NAME_KSH"

MASTER_FILE_NAME=
RUN_TESTS_ARGS=
VERBOSE_MODE=FALSE

typeset -l LOWERCASE_ARG
while [ "$#" -ne 0 ]
do
   LOWERCASE_ARG="$1"
   case $LOWERCASE_ARG in
      *)  if [ "$CODE_COVERAGE_EXECUTABLE_NAME" = "" ] ; then
             case $LOWERCASE_ARG in
                -masterfilename)
                    MASTER_FILE_NAME="$2"
                    shift
                    shift ;;
                -stats)
                    RUN_TESTS_ARGS="$RUN_TESTS_ARGS -Stats"
                    shift ;;
                -verbose)
                    RUN_TESTS_ARGS="$RUN_TESTS_ARGS -Verbose"
                    VERBOSE_MODE=TRUE
                    shift ;;
                -?) Usage
                    shift ;;
                *)  CODE_COVERAGE_EXECUTABLE_NAME="$1"
                    shift ;;
             esac
          elif [ "$CODE_COVERAGE_EXECUTABLE_ARGS" = "" ] ; then
             CODE_COVERAGE_EXECUTABLE_ARGS="$1"
             shift
          else
             CODE_COVERAGE_EXECUTABLE_ARGS="${CODE_COVERAGE_EXECUTABLE_ARGS}${CODE_COVERAGE_ARG_SEPARATOR}$1"
             shift
          fi
          ;;
   esac
done

if [ "$MASTER_FILE_NAME" = "" ] ; then
   MASTER_GUID=`C4.sh GetGuid -HashString \
         "${CODE_COVERAGE_EXECUTABLE_NAME}@${CODE_COVERAGE_EXECUTABLE_ARGS}"`
   MASTER_FILE_NAME="$CODE_COVERAGE_EXECUTABLE_NAME.$MASTER_GUID.coverage"
fi

UNIT_TEST_DLL="$EZ_CFOUR_ROOT/DNetBin/C4UnitTest.dll"
if [ ! -f "$UNIT_TEST_DLL" ] ; then
   echo "ERROR: Failed to find unit test dll $UNIT_TEST_DLL."
   exit 1
fi

if [ "$VERBOSE_MODE" = TRUE ] ; then
   echo "CODE_COVERAGE_ARG_SEPARATOR=$CODE_COVERAGE_ARG_SEPARATOR"
   echo "CODE_COVERAGE_EXECUTABLE_NAME=$CODE_COVERAGE_EXECUTABLE_NAME"
   echo "CODE_COVERAGE_EXECUTABLE_ARGS=$CODE_COVERAGE_EXECUTABLE_ARGS"
   echo "CODE_COVERAGE_OUTPUT_FILE_NAME=$CODE_COVERAGE_OUTPUT_FILE_NAME"
fi

RunDllTests.sh -ClassNames RunExecutableTest -CodeCoverage $RUN_TESTS_ARGS \
      -CatFileName "$OUTPUT_FILE_NAME_KSH" -Quiet \
      -MasterFileName "$MASTER_FILE_NAME" $UNIT_TEST_DLL

rm -f "$CODE_COVERAGE_OUTPUT_FILE_NAME"
rm -rf TestResults

unset CODE_COVERAGE_ARG_SEPARATOR
unset CODE_COVERAGE_EXECUTABLE_NAME
unset CODE_COVERAGE_EXECUTABLE_ARGS
unset CODE_COVERAGE_OUTPUT_FILE_NAME
