'---------------------------------------------------------------------------
' FileName: <<FileName>>
'   Author: Craig Schneider
'  Created: 2003-04-09
' Synopsis: Perform any necessary post build actions.
' <<Copyright>>
'---------------------------------------------------------------------------

Option Explicit

Dim mPostBuildVersion
    mPostBuildVersion = "4.33"

Dim mFileSys
Set mFileSys = CreateObject("Scripting.FileSystemObject")

Dim mCurrentDir
Dim mBinDirArray
    mBinDirArray = Array(".\bin\Debug\net462", _
                         ".\bin\Debug\net451", _
                         ".\bin\Debug\netstandard2.0", _
                         ".\bin\Debug\netcoreapp2.0", _
                         ".\bin\Debug", _
                         ".\bin", _
                         ".")
Dim mCurrentBinDir
For Each mCurrentBinDir In mBinDirArray
   If mFileSys.FolderExists(mCurrentBinDir) Then
      Set mCurrentDir = mFileSys.GetFolder(mCurrentBinDir)
      Exit For
   End If
Next

Dim mDeployToSubDir
    mDeployToSubDir = ""

Dim mPDB
    mPDB = True

Dim mDeployDirArray
    mDeployDirArray = Array("..\..\DNetBin",          _
                            "..\..\..\DNetBin",       _
                            "..\..\..\..\DNetBin",    _
                            "..\..\..\..\..\DNetBin", _
                            "..\..\..\..\..\..\DNetBin")

'---------------------------------------------------------------------------
' Argument processing.
'---------------------------------------------------------------------------
Dim ArgNum
    ArgNum = 0
While ArgNum < WScript.Arguments.Count
   Select Case LCase(WScript.Arguments(ArgNum))
      Case "-nopdb":           mPDB = False
      Case "-subdir":          ArgNum = ArgNum + 1
                               mDeployToSubDir = WScript.Arguments(ArgNum)
      Case "-?":               ShowUsage
      Case Else:               ShowUsage
   End Select

   ArgNum = ArgNum + 1
Wend

'---------------------------------------------------------------------------
' The MAIN.
'---------------------------------------------------------------------------

Dim mCurrentDeployDir
For Each mCurrentDeployDir In mDeployDirArray
   If mFileSys.FolderExists(mCurrentDeployDir) Then
      DeployTo mCurrentDeployDir, mDeployToSubDir 
      ExitSuccessfully  ' No where to deploy does not fail build.
   End If
Next

WScript.Echo "Warning: Failed to find runtime DNetBin dir for " & mCurrentDir.Path
ExitSuccessfully  ' No where to deploy does not fail build.

'---------------------------------------------------------------------------
'---------------------------------------------------------------------------
Sub DeployTo(DeployRootDirName, DeploySubDirName)
   Dim mDeployRootDir
   Set mDeployRootDir = mFileSys.GetFolder(DeployRootDirName)

   ' First deploy the bins
   Dim mDeployBinDirName
   mDeployBinDirName = mDeployRootDir.Path
   If DeploySubDirName <> "" Then
      mDeployBinDirName = mDeployBinDirName & "\" & DeploySubDirName
   End If
   If Not mFileSys.FolderExists(mDeployBinDirName) Then
      mFileSys.CreateFolder(mDeployBinDirName)
      WScript.Echo "Successfully created dir " & mDeployBinDirName & "."
   End If

   Dim mCurrentFile
   Dim mCurrentExt
   Dim mCurrentExtCfg
   Dim SourceFileName
   Dim SourceFileFullName
   Dim RunningFileName
   Dim RunningFileFullName
   Dim TargetFileFullName
   For Each mCurrentFile In mCurrentDir.Files
      SourceFileName = mCurrentFile.Name
      mCurrentExt    = Right(LCase(SourceFileName), 3)
      mCurrentExtCfg = Right(LCase(SourceFileName), 10)
      If (Right(LCase(SourceFileName), 10) <> "vshost.exe") AND _
         (Right(LCase(SourceFileName), 17) <> "vshost.exe.config") AND _
         ((mCurrentExt = "dll" OR  mCurrentExtCfg = "dll.config" OR _
           mCurrentExt = "exe" OR  mCurrentExtCfg = "exe.config") OR _
          (mCurrentExt = "pdb" AND mPDB)) Then
         SourceFileFullName = mCurrentDir.Path & "\" & SourceFileName
         TargetFileFullName = mDeployBinDirName & "\" & SourceFileName
         Dim IsDeployed
         IsDeployed = False
         Dim RunningNum
         RunningNum = 0
         While Not IsDeployed AND RunningNum < 10
            If RunningNum > 0 Then
               RunningFileName = SourceFileName & "." & RunningNum & _
                                 ".running"
               RunningFileFullName = mDeployBinDirName & "\" & RunningFileName
               On Error Resume Next
               mFileSys.DeleteFile RunningFileFullName
               On Error Resume Next
               mFileSys.MoveFile TargetFileFullName, RunningFileFullName
               If Err = 0 Then
                  WScript.Echo "Successfully created running file " & _
                                RunningFileName
               End If
            End If
            On Error Resume Next
            mFileSys.CopyFile SourceFileFullName, TargetFileFullName, True
            If Err = 0 Then
               IsDeployed = True
            End If
            On Error GoTo 0
            RunningNum = RunningNum + 1
         Wend
         If IsDeployed Then
            WScript.Echo "Successfully deployed " & TargetFileFullName & "."
         Else
            WScript.Echo "ERROR: Failed to deploy file " & SourceFileName & _
                         " to " & mDeployBinDirName & "."
         End If
      End If
   Next
End Sub

'---------------------------------------------------------------------------
'---------------------------------------------------------------------------
Function After(InitialString, SearchString)
   Dim Spot
   Spot = InStr(InitialString, SearchString)
   If Spot >= 0 Then
      After = Right(InitialString, Len(InitialString) - _
                    Len(SearchString) - Spot + 1)
   Else
      After = InitialString
   End If
End Function

'---------------------------------------------------------------------------
'---------------------------------------------------------------------------
Function AfterLast(InitialString, SearchString)
   Dim Spot
   Spot = InStrRev(InitialString, SearchString)
   If Spot >= 0 Then
      AfterLast = Right(InitialString, Len(InitialString) - _
                    Len(SearchString) - Spot + 1)
   Else
      AfterLast = InitialString
   End If
End Function

'---------------------------------------------------------------------------
'---------------------------------------------------------------------------
Function Before(InitialString, SearchString)
   Dim Spot
   Spot = InStr(InitialString, SearchString)
   If Spot > 0 Then
      Before = Left(InitialString, Spot - 1)
   Else
      Before = InitialString
   End If
End Function

'---------------------------------------------------------------------------
'---------------------------------------------------------------------------
Function BeforeLast(InitialString, SearchString)
   Dim Spot
   Spot = InStrRev(InitialString, SearchString)
   If Spot > 0 Then
      BeforeLast = Left(InitialString, Spot - 1)
   Else
      BeforeLast = InitialString
   End If
End Function

'---------------------------------------------------------------------------
'---------------------------------------------------------------------------
Sub ShowUsage()
 WScript.Echo _
 "Usage: DNetPostBuild.vbs [-NoPDB] [-?]" & _
 vbCRLF
   WScript.Quit 1
End Sub

'---------------------------------------------------------------------------
'---------------------------------------------------------------------------
Sub ExitSuccessfully()
   WScript.Echo "Successfully executed DNetPostBuild.vbs version " & _
                mPostBuildVersion & "."
   WScript.Quit 0
End Sub
