#===========================================================================
#  Filename: FeedFilesList.ksh
#    Author: Craig Schneider
# Orig Date: 05/16/2017
# Copyright: ShadowScape Technologies, Inc. (see copyright file for details)
#  Synopsis: List the feed files for the specified feed name.
#===========================================================================

FEED_NAME="CATS"
DIR_FORMAT=FALSE

function Usage
{
   if [ "$1" != "" ] ; then
      echo
      echo "$1"
   fi
   cat <<!

Usage: FeedFilesList -Feed <FeedName> [-DirFormat]

  -DirFormat: Display the list using the directory output format.
       -Feed: The name of the feed to show the files for (default $FEED_NAME).
!
   exit 1
}

typeset -l LOWERCASE_ARG
while [ "$#" -ne 0 ]
do
   LOWERCASE_ARG="$1"
   case $LOWERCASE_ARG in
    -dirformat) DIR_FORMAT=TRUE
                shift ;;
         -feed) FEED_NAME="$2"
                shift
                shift ;;
             *) if [ "$1" != "-?" ] ; then
                   Usage "Invalid argument: $1"
                else
                   Usage
                fi ;;
   esac
done

GLOBAL_FILES_DIR="C:/GlobalFiles"
LOCAL_FILES_DIR="C:/LocalFiles"
ERRORS_FEED_DIR="$GLOBAL_FILES_DIR/InputDataFeedErrors/$FEED_NAME/Error"
INBOUND_FEED_DIR="$GLOBAL_FILES_DIR/LandingZone/Inbound/$FEED_NAME"
LOCAL_FEED_DIR="$LOCAL_FILES_DIR/InputDataFeeds/$FEED_NAME"
ARCHIVE_FEED_DIR="$LOCAL_FILES_DIR/InputDataFeeds/Archive/$FEED_NAME"

LOCAL_ARCHIVE_DIRS=
if [ -d "$ARCHIVE_FEED_DIR" ] ; then
   LOCAL_ARCHIVE_DIRS=`ls -d $ARCHIVE_FEED_DIR/* 2>&1 | \
       egrep -v 'No such file or directory'`
fi
ERROR_CATEGORY_DIRS=
if [ -d "$ERRORS_FEED_DIR" ] ; then
   ERROR_CATEGORY_DIRS=`ls -d $ERRORS_FEED_DIR/* 2>&1 | \
       egrep -v 'No such file or directory'`
fi
SOURCE_ARCHIVE_DIRS=
if [ -d "$INBOUND_FEED_DIR/Archive" ] ; then
   for SOURCE_ARCHIVE_DATE_DIR in `ls -d $INBOUND_FEED_DIR/Archive/* 2>&1 | \
       egrep -v 'No such file or directory'`
   do
      SOURCE_ARCHIVE_DIRS="$SOURCE_ARCHIVE_DIRS $SOURCE_ARCHIVE_DATE_DIR"
      if [ -d "$SOURCE_ARCHIVE_DATE_DIR/Dup" ] ; then
         SOURCE_ARCHIVE_DIRS="$SOURCE_ARCHIVE_DIRS $SOURCE_ARCHIVE_DATE_DIR/Dup"
      fi
   done
fi
for DIRECTORY in $INBOUND_FEED_DIR      \
                 $SOURCE_ARCHIVE_DIRS   \
                 $LOCAL_FEED_DIR/Input  \
                 $LOCAL_FEED_DIR/Parse  \
                 $LOCAL_FEED_DIR/Load   \
                 $LOCAL_ARCHIVE_DIRS    \
                 $ERRORS_FEED_DIR       \
                 $ERROR_CATEGORY_DIRS
do
   if [ -d "$DIRECTORY" ] ; then
      if [ "$DIR_FORMAT" = TRUE ] ; then
         echo "Directory: $DIRECTORY"
      fi
      for FILE_OR_DIR in `ls $DIRECTORY`
      do
         if [ -f "$DIRECTORY/$FILE_OR_DIR" ] ; then
            if [ "$DIR_FORMAT" = TRUE ] ; then
               echo "     File: $FILE_OR_DIR"
            else
               echo "$DIRECTORY/$FILE_OR_DIR"
            fi
         #else
            #echo "      Dir: $FILE_OR_DIR"
         fi
      done
   else
      if [ "$DIR_FORMAT" = TRUE ] ; then
         echo "  Missing: $DIRECTORY"
      fi
   fi
done
if [ "$DIR_FORMAT" = TRUE ] ; then
   if [ ! -d "$ARCHIVE_FEED_DIR" ] ; then
      echo "  Missing: $ARCHIVE_FEED_DIR"
   fi
   if [ ! -d "$INBOUND_FEED_DIR/Archive" ] ; then
      echo "  Missing: $INBOUND_FEED_DIR/Archive"
   fi
fi
