#===========================================================================
#  Filename: Kshs2Unix.ksh
#    Author: Craig Schneider
# Orig Date: 01/02/11
# Copyright: ShadowScape Technologies, Inc. (see copyright file for details)
#  Synopsis: Fix all ksh files for use by CYGWIN.
#===========================================================================

#===========================================================================
# Display the usage.
#===========================================================================
function Usage
{
   if [ "$1" != "" ] ; then
      echo
      echo $*
   fi
   cat <<!

   Usage: $0 [FileOrDirName(s)...]

!
   exit 1
}

FILE_OR_DIR_LIST=

while [ $# -ne 0 ]
do
   case "$1" in
      -*) if [ "$1" != "-?" ] ; then
             Usage "Invalid argument: $1"
          else
             Usage
          fi ;;
      *) FILE_OR_DIR_LIST="$FILE_OR_DIR_LIST $1"
         shift ;;
   esac
done

if [ "$FILE_OR_DIR_LIST" = "" ] ; then
   FILE_OR_DIR_LIST="$EZ_FAM_ROOTS"
fi

function FixKshFile {
   KSH_FILE="$1"
   KSH_FILE_UNIX="$1.fix"
   cp "$KSH_FILE" "$KSH_FILE_UNIX"
   dos2unix -q "$KSH_FILE_UNIX" 
   cmp -s "$KSH_FILE" "$KSH_FILE_UNIX"
   if [ $? -ne 0 ] ; then
      src.ksh stabalize -yes -r "$KSH_FILE_UNIX" "$KSH_FILE" \
        -t Stabalized "Successfully converted to unix style $KSH_FILE."
   else
      rm -f "$KSH_FILE_UNIX"
      echo "Successfully skipping unix style file $KSH_FILE."
   fi
}

for FILE_OR_DIR in $FILE_OR_DIR_LIST
do
   if [ -d "$FILE_OR_DIR" ] ; then
      cd $FILE_OR_DIR
      FILE_NAME_WITH_SPACES=
      for KSH_FILE in `find . -name \*.ksh`
      do
         if [ -f "$KSH_FILE" ] ; then
            FixKshFile "$KSH_FILE"
            FILE_NAME_WITH_SPACES=
         else
            if [ "$FILE_NAME_WITH_SPACES" = "" ] ; then
               FILE_NAME_WITH_SPACES="$KSH_FILE"
            else
               FILE_NAME_WITH_SPACES="$FILE_NAME_WITH_SPACES $KSH_FILE"
               if [ -f "$FILE_NAME_WITH_SPACES" ] ; then
                  FixKshFile "$FILE_NAME_WITH_SPACES"
                  FILE_NAME_WITH_SPACES=
               fi 
            fi
         fi
      done
   elif [ -f "$FILE_OR_DIR" ] ; then
      FixKshFile "$FILE_OR_DIR"
   fi
done

exit 0
