#===========================================================================
#  Filename: NewWindow.ksh
#    Author: Craig Schneider
# Orig Date: 10/30/13
# Copyright: ShadowScape Technologies, Inc. (see copyright file for details)
#  Synopsis: Start the specified command in a new window.
#===========================================================================

. $EZ_SHARED_ENV

#===========================================================================
# Display the usage.
#===========================================================================
function Usage
{
   if [ "$1" != "" ] ; then
      echo
      echo $*
   fi
   cat <<!

Usage: NewWindow [-CurrentWindow] [Command CommandArgs...]
                 [-CommandFile CommandFileName] [-Dots] [-RemoveCommandFile]
                 [-Wait]

     CurrentWindow: Execute the command in the current window.
           Command: The command to be executed in the new window.
       CommandArgs: The arguments to the Command.
       CommandFile: A file name containing the commands to execute.
              Dots: Display dots indicating that we are waiting.
 RemoveCommandFile: Remove the command file after executing it.
              Wait: Wait for the command to complete before exiting.

!
   exit 1
}

#===========================================================================
# Process the command line arguments.
#===========================================================================

COMMAND_FILE=
DOTS=FALSE
NEW_WINDOW_ARGS=
NEW_WINDOW=TRUE
PAUSE=FALSE
REMOVE_CMD_FILE=FALSE
REMOVE_THIS_FILE=
WAIT_FOR_CMD=FALSE

typeset -l LOWERCASE_ARG
while [ $# -ne 0 ]
do
   LOWERCASE_ARG="$1"
   case $LOWERCASE_ARG in
      -commandfile)
          COMMAND_FILE="$2"
          NEW_WINDOW_ARGS="-CommandFile $2"
          shift
          shift ;;
      -currentwindow)
          NEW_WINDOW=FALSE
          shift ;;
      -pause)
          PAUSE=TRUE
          shift ;;
      -removecommandfile)
          REMOVE_CMD_FILE=TRUE
          shift ;;
      -removethisfile)
          REMOVE_THIS_FILE="$2"
          shift
          shift ;;
      -wait)
          WAIT_FOR_CMD=TRUE
          shift ;;
       *) if [ "$1" = "-?" ] ; then
             Usage
          fi
          NEW_WINDOW_ARGS="$NEW_WINDOW_ARGS $1"
          shift ;;
    esac
done

if [ "$NEW_WINDOW_ARGS" = "" ] ; then
   Usage "Must specify a command to execute."
fi

if [ "$NEW_WINDOW" = TRUE ] ; then
   NEW_WINDOW_FILE=`EZPath2Ksh $EZ_FAMILYTREE_ROOT/Scripts/NewWindow.ksh`
   if [ ! -f "$NEW_WINDOW_FILE" ] ; then
      NEW_WINDOW_FILE=`EZPath2Ksh $EZ_ENV_ROOT/Scripts/NewWindow.ksh`
   fi
   NEW_WINDOW_CMD_FILE="$TMPDIR/NewWindow.$$.ksh"
   cat > "$NEW_WINDOW_CMD_FILE" <<!
$NEW_WINDOW_FILE -CurrentWindow -Pause -RemoveThisFile \
        "$NEW_WINDOW_CMD_FILE" $NEW_WINDOW_ARGS
!
   chmod 777 "$NEW_WINDOW_CMD_FILE"
   cygstart /usr/bin/mksh -c "$NEW_WINDOW_CMD_FILE"
   if [ "$WAIT_FOR_CMD" = TRUE ] ; then

      while [ -f "$NEW_WINDOW_CMD_FILE" ]
      do
         if [ "$DOTS" = TRUE ] ; then
            echo -n "."
         fi
         sleep 1
      done
   fi
else
   if [ "$COMMAND_FILE" != "" ] ; then
      chmod 777 "$COMMAND_FILE"
      $COMMAND_FILE
      if [ "$REMOVE_CMD_FILE" = TRUE ] ; then
         rm -f "$COMMAND_FILE"
      fi
   else
      $NEW_WINDOW_ARGS
   fi
   if [ "$REMOVE_THIS_FILE" != "" ] ; then
      rm -f "$REMOVE_THIS_FILE"
   fi
   if [ "$PAUSE" = TRUE ] ; then
      echo
      echo "******* Press enter to exit... \c"
      read ANSWER
   fi
fi
exit 0
