#===========================================================================
#  Filename: NightlyTasks.ksh
#    Author: Craig Schneider
# Orig Date: 05/15/13
# Copyright: ShadowScape Technologies, Inc. (see copyright file for details)
#  Synopsis: Perform NightlyTasks.
#===========================================================================

. $EZ_SHARED_ENV

function Usage
{
   if [ "$1" != "" ] ; then
      echo
      echo "$1"
   fi
   cat <<!

Usage: NightlyTasks [-3rdPurge] [-Clobber] [-Host RemoteHost] [-Mk]
                    [-MkLists] [-NewWindow] [-Nuke] [-Pause]
                    [-Refresh] [-RepoBackup] [-Timing]

    -3rdPurge: Perform a purge of the 3rdParty directory.
     -Clobber: Perform a mk clobber from the top.
        -Host: Specifies the name of the remote host execute tasks on.
          -Mk: Perform the top level mk operation.
     -MkLists: Perform the mk_lists command to make the f & j lists.
   -NewWindow: Display the results in a new window.
        -Nuke: Perform the rel nuke operation to nuke old releases.
       -Pause: Pause for the user to press enter at the end of execution.
     -Refresh: Perform a refresh of the source code.
  -RepoBackup: Perform the src repo_backup operation to backup the source code.
      -Timing: Display timing information on some messages.

!
   exit 1
}

DO_3RD_PURGE=FALSE
MK_ALL=FALSE
MK_CLOBBER=FALSE
MK_LISTS=FALSE
PAUSE=FALSE
REL_NUKE=FALSE
REMOTE_RUN_ARGS="NightlyTasks.ksh"
RUN_ON_HOST="$EZ_COMPUTERNAME"
SRC_REPO_BACKUP=FALSE
SRC_REFRESH=FALSE
TIMING=FALSE

typeset -l LOWERCASE_ARG
while [ "$#" -ne 0 ]
do
   LOWERCASE_ARG="$1"
   case $LOWERCASE_ARG in
      -3rdpurge) DO_3RD_PURGE=TRUE
                 REMOTE_RUN_ARGS="$REMOTE_RUN_ARGS $LOWERCASE_ARG"
                 shift ;;
       -clobber) MK_CLOBBER=TRUE
                 REMOTE_RUN_ARGS="$REMOTE_RUN_ARGS $LOWERCASE_ARG"
                 shift ;;
          -host) RUN_ON_HOST="$2"
                 REMOTE_RUN_ARGS="$REMOTE_RUN_ARGS -h $2"
                 shift
                 shift ;;
            -mk) MK_ALL=TRUE
                 REMOTE_RUN_ARGS="$REMOTE_RUN_ARGS $LOWERCASE_ARG"
                 shift ;;
       -mklists) MK_LISTS=TRUE
                 REMOTE_RUN_ARGS="$REMOTE_RUN_ARGS $LOWERCASE_ARG"
                 shift ;;
     -newwindow) REMOTE_RUN_ARGS="$REMOTE_RUN_ARGS $LOWERCASE_ARG"
                 shift ;;
          -nuke) REL_NUKE=TRUE
                 REMOTE_RUN_ARGS="$REMOTE_RUN_ARGS $LOWERCASE_ARG"
                 shift ;;
         -pause) PAUSE=TRUE
                 shift ;;
       -refresh) SRC_REFRESH=TRUE
                 REMOTE_RUN_ARGS="$REMOTE_RUN_ARGS $LOWERCASE_ARG"
                 shift ;;
    -repobackup) SRC_REPO_BACKUP=TRUE
                 REMOTE_RUN_ARGS="$REMOTE_RUN_ARGS $LOWERCASE_ARG"
                 shift ;;
        -timing) TIMING=TRUE
                 shift ;;
              *) if [ "$1" != "-?" ] ; then
                    Usage "Invalid argument $1"
                 else
                    Usage
                 fi
                 shift ;;
   esac
done

OPERATION="unknown operation"
if [ "$DO_3RD_PURGE" = TRUE ] ; then
   OPERATION="3rd party purge"
fi
if [ "$REL_NUKE" = TRUE ] ; then
   OPERATION="release nuke"
fi
if [ "$SRC_REPO_BACKUP" = TRUE ] ; then
   OPERATION="repository backup"
fi
if [ "$MK_ALL" = TRUE ] ; then
   OPERATION="nightly refresh"
fi

if [ "$RUN_ON_HOST" != "$EZ_COMPUTERNAME" ] ; then
   if [ "$TIMING" = TRUE ] ; then
      echo "[$(date '+%D %T')] \c"
   fi
   echo "Successfully running $OPERATION on $RUN_ON_HOST."

   RemoteRun.ksh $REMOTE_RUN_ARGS

   if [ "$PAUSE" = TRUE ] ; then
      echo
      echo
      echo "******* Press enter to exit $OPERATION on $RUN_ON_HOST... \c"
      read ANSWER
   else
      if [ "$TIMING" = TRUE ] ; then
         echo "[$(date '+%D %T')] \c"
      fi
      echo "Successfully finished $OPERATION on $RUN_ON_HOST."
   fi
   exit 0
fi

if [ "$SRC_REFRESH" = TRUE ] ; then
   src.ksh refresh -a
fi

if [ "$REL_NUKE" = TRUE ] ; then
   rel.sh nuke
fi

if [ "$MK_LISTS" = TRUE ] ; then
   mk_lists.ksh
fi

if [ "$MK_CLOBBER" = TRUE ] ; then
   top
   mk clobber
fi

if [ "$MK_ALL" = TRUE ] ; then
   . "$EZ_PROFILE_FILE"
   top
   mk
fi

if [ "$DO_3RD_PURGE" = TRUE ] ; then
   rel.sh 3rd_purge
fi

if [ "$SRC_REPO_BACKUP" = TRUE ] ; then
   src.ksh repo_backup
fi

if [ "$PAUSE" = TRUE ] ; then
   echo
   echo
   echo "******* Press enter to exit $OPERATION on $RUN_ON_HOST... \c"
   read ANSWER
else
   if [ "$TIMING" = TRUE ] ; then
      echo "[$(date '+%D %T')] \c"
   fi
   echo "Successfully finished $OPERATION on $RUN_ON_HOST."
fi
exit 0
