#===========================================================================
#  Filename: RemoteRun.ksh
#    Author: Craig Schneider
# Orig Date: 07/10/01
# Copyright: ShadowScape Technologies, Inc. (see copyright file for details)
#  Synopsis: Run commands on alternate hosts using the file system as a
#            communication mechanism.
#===========================================================================

. $EZ_SHARED_ENV

VERBOSE_MODE=FALSE
DAEMON_MODE=FALSE
DEAMON_COMPUTER_NAME=$EZ_COMPUTERNAME
REMOTE_COMMAND=
REMOTE_HOST=DetermineHost
WINDOW_ARG="-CurrentWindow"
NEW_WINDOW_ARGS=

function Usage
{
   if [ "$1" != "" ] ; then
      echo
      echo $1
   fi
   cat <<!

Usage: $0 -daemon [-name PseudoComputerName] [-verbose]

                        -- OR -- 

Usage: $0 -h RemoteHost [-NewWindow] [-Wait] Command [CommandArguments...]

!
   exit 1
}

typeset -l LOWERCASE_ARG
while [ $# -ne 0 ]
do
   LOWERCASE_ARG="$1"
   case $LOWERCASE_ARG in
    -deamon|-daemon) 
              DAEMON_MODE=TRUE
              shift ;;
    -h|-host) REMOTE_HOST="$2"
              shift
              shift ;;
    -name)    DEAMON_COMPUTER_NAME="$2"
              shift
              shift ;;
    -newwindow) 
              WINDOW_ARG=
              shift ;;
    -verbose) VERBOSE_MODE=TRUE
              shift ;;
    -wait)    NEW_WINDOW_ARGS="$NEW_WINDOW_ARGS $1"
              shift ;;
           *) if [ "$1" = "-?" ] ; then
                 Usage
              else
                 REMOTE_COMMAND="$REMOTE_COMMAND $1"
              fi
              shift ;;
   esac
done

if [ "$DAEMON_MODE" = TRUE -a "$REMOTE_HOST" != "DetermineHost" ] ; then
   Usage
fi
if [ "$DAEMON_MODE" = FALSE -a "$REMOTE_HOST" = "DetermineHost" ] ; then
   Usage
fi
if [ "$DAEMON_MODE" = FALSE -a "$REMOTE_HOST" = "" ] ; then
   Usage
fi
if [ "$DAEMON_MODE" = FALSE -a "$REMOTE_COMMAND" = "" ] ; then
   Usage
fi

if [ "$EZ_REMOTE_RUN_ROOT" != "" ] ; then
   REMOTE_DIR="$EZ_REMOTE_RUN_ROOT"
else
   REMOTE_DIR=$EZ_ARCHIVE_ROOT/RemoteRun
fi
if [ ! -d "$REMOTE_DIR" ] ; then
   mkdir -p "$REMOTE_DIR"
   chmod 777 "$REMOTE_DIR"
fi

REMOTE_DIR_KSH=`EZPath2Ksh "$REMOTE_DIR"`
cd "$REMOTE_DIR_KSH"
if [ $? -ne 0 ] ; then
   echo "ERROR: Failed changing to remote run directory $REMOTE_DIR."
   exit 1
fi

if [ "$DAEMON_MODE" = TRUE ] ; then

   passes=0
   interval=50
   while true
   do
      let interval=interval+1
      if [ $interval -ge 50 ] ; then
         interval=0
         echo
         echo -n "Passes Completed $passes	"
      else
         echo -n "."
      fi
      let passes=passes+1

      COMMAND_FILE_LIST=`echo $DEAMON_COMPUTER_NAME.*.run`
      if [ "$COMMAND_FILE_LIST" = "$DEAMON_COMPUTER_NAME.*.run" ] ; then
         sleep 2
         continue
      fi
      for COMMAND_FILE in $COMMAND_FILE_LIST
      do
         if [ -f ${COMMAND_FILE%.run}.running ] ; then
            echo "\nSkipping commands in file $COMMAND_FILE since running."
            sleep 2
            continue
         fi
         cat <<!


###############################################################################
Running Commands in file $COMMAND_FILE
###############################################################################
!
         RUNNING_FILE=${COMMAND_FILE%.run}.running
         OUTPUT_FILE=${COMMAND_FILE%.run}.out
         mine.sh $COMMAND_FILE
         if [ "$VERBOSE_MODE" = TRUE ] ; then
            echo "$COMMAND_FILE contents:"
            cat $COMMAND_FILE
         fi
         $COMMAND_FILE 2>&1 | tee $RUNNING_FILE
         mv $RUNNING_FILE $OUTPUT_FILE
         rm -f $COMMAND_FILE
      done
      echo
      echo -n "Passes Completed $passes	"
   done

else

   if [ "$REMOTE_HOST" = "DetermineHost" ] ; then
      echo "ERROR: Failed to determine remote host for user $LOGNAME."
      exit 1
   fi

   CMD_PREFIX=$REMOTE_HOST.$$
   CMD_TMP=$CMD_PREFIX.tmp
   CMD_RUN=$CMD_PREFIX.run
   RUNNING_FILE=$CMD_PREFIX.running
   OUTPUT_FILE=$CMD_PREFIX.out
   echo "$REMOTE_COMMAND" > $CMD_TMP
   chmod 777 --silent $CMD_TMP 
   mv $CMD_TMP $CMD_RUN
   while true
   do
      sleep 1
      if [ -f "$OUTPUT_FILE" ] ; then
         CAT_CMD_FILE="$TMPDIR/RemoteCat.$$.ksh"
         cat > "$CAT_CMD_FILE" <<!
cat "$REMOTE_DIR_KSH/$OUTPUT_FILE"
rm -f "$REMOTE_DIR_KSH/$OUTPUT_FILE"
!
         NewWindow.ksh $NEW_WINDOW_ARGS $WINDOW_ARG -RemoveCommandFile \
                       -CommandFile $CAT_CMD_FILE
         break
      fi
   done
fi
exit 0
