#===========================================================================
# FileName: <<FileName>>
#   Author: Craig Schneider
#  Created: 2010-10-27
# Synopsis: Run dotnet tests for .csproj files.
# <<Copyright>>
#===========================================================================

. $EZ_SHARED_ENV

SHOW_SUMMARY=PROMPT
TEST_CSPROJ_LIST=

function Usage
{
   if [ "$1" != "" ] ; then
      echo
      echo "$1"
   fi
   cat <<!

Usage: RunTests [-DryRun] [TestCSProjName ...]


        -DryRun: Display the commands to be executed, without executing them.
 TestCSProjName: Specifies a list of test .csproj file names.

!
   exit 1

   cat <<!

Usage: RunTests [-ClassNames ClassName,...] [-CodeCoverage] [-DryRun] 
                [-Filter Filter] [-MasterFileName MasterFileName] 
                [-NoSummary] [-Passes Passes] [-Performance]
                [-Quiet] [-r ResultsFileName] [-Slow] [-StackTrace] [-Stats]
                [-TestNames TestName,...] [-TestCategories Category,...]
                [-Unattended] [TestDLLName ...] [-Verbose]

    -ClassNames: Specifies a list of test class names to be run.
  -CodeCoverage: Enables the generation of code coverage data.
        -DryRun: Display the commands to be executed, without executing them.
        -Filter: The TestCaseFilter to apply to the tests.
-MasterFileName: The master coverage file name to use.
     -NoSummary: Disables display of the summary of failed tests.
        -Passes: The number of total passes to run for tests that support it.
   -Performance: Equivalent to specifying -category performance.
         -Quiet: Suppress non critical messages about operations performed.
             -r: Specifies the results file name to copy the results into.
          -Slow: Execute slow tests as well.
    -StackTrace: Specifies if the stack for failed tests is output.
         -Stats: Display the CodeCoverage Stats for this run.
-TestCategories: Specifies a list of test categories to be run.
     -TestNames: Specifies a list of test names to be run.
    -Unattended: Specifies to run the tests in unattended mode.
    TestDLLName: Specifies a list of test dll names.
       -Verbose: Display verbose messages about operations being performed.

       EXAMPLES:

       RunTests -ClassNames AppBaseTest C4BaseCoreTest.dll

       RunTests -TestCategories Hangs C4BaseCoreTest.dll

       RunTests -TestNames WeekOfMonth,WordWrap C4BaseCoreTest.dll

       RunTests -Filter FullyQualifiedName~AppBaseTest.Run C4BaseCoreTest.dll

!
   exit 1
}

#export TEST_TOTAL_PASSES=1
#export TEST_SLOW=FALSE
#CLASS_FILTER=
#CATEGORY_FILTER=
#CAT_FILE_FULL_NAME=
#CODE_COVERAGE=FALSE
#EZ_DRYRUN=FALSE
#MASTER_FILE_NAME=
#QUIET_MODE=FALSE
#STACK_TRACE=FALSE
#STATS_MODE=FALSE
#VERBOSE_MODE=FALSE
#RESULTS_FILE_NAME=
#VSTEST_ARGS="/InIsolation"
#X64_MODE=TRUE

typeset -l LOWERCASE_ARG
while [ "$#" -ne 0 ]
do
   LOWERCASE_ARG="$1"
   case $LOWERCASE_ARG in
#      -catfilename)
#          CAT_FILE_FULL_NAME="$2"
#          shift
#          shift ;;
#      -classnames|-classname)
#          CLASS_FILTER=
#          for CLASS_NAME in `echo $2 | sed -e 's/,/ /g'`
#          do
#              if [ "$CLASS_FILTER" != "" ] ; then
#                 CLASS_FILTER="${CLASS_FILTER}|"
#              fi
#              CLASS_FILTER="${CLASS_FILTER}FullyQualifiedName~.${CLASS_NAME}."
#          done
#          VSTEST_ARGS="$VSTEST_ARGS /TestCaseFilter:$CLASS_FILTER"
#          shift
#          shift ;;
#      -codecoverage)
#          VSTEST_ARGS="$VSTEST_ARGS /EnableCodeCoverage"
#          CODE_COVERAGE=TRUE
#          shift ;;
      -dryrun)
          EZ_DRYRUN=TRUE
          shift ;;
#      -filter)
#          VSTEST_ARGS="$VSTEST_ARGS /TestCaseFilter:$2"
#          shift
#          shift ;;
#      -masterfilename)
#          MASTER_FILE_NAME="$2"
#          shift
#          shift ;;
#      -nosummary)
#          SHOW_SUMMARY=FALSE
#          shift ;;
#      -passes)
#          export TEST_TOTAL_PASSES="$2"
#          shift
#          shift ;;
#      -performance)
#          VSTEST_ARGS="$VSTEST_ARGS /TestCaseFilter:Name~Performance"
#          shift ;;
#      -quiet)
#          QUIET_MODE=TRUE
#          shift ;;
#      -r) RESULTS_FILE_NAME="$2"
#          shift
#          shift ;;
#      -slow)
#          export TEST_SLOW=TRUE
#          shift ;;
#      -stacktrace)
#          export STACK_TRACE=TRUE
#          shift ;;
#      -stats)
#          export STATS_MODE=TRUE
#          shift ;;
#      -testcategories)
#          CATEGORY_FILTER=
#          for CATEGORY_NAME in `echo $2 | sed -e 's/,/ /g'`
#          do
#              if [ "$CATEGORY_FILTER" != "" ] ; then
#                 CATEGORY_FILTER="${CATEGORY_FILTER}|"
#              fi
#              CATEGORY_FILTER="${CATEGORY_FILTER}TestCategory=${CATEGORY_NAME}"
#          done
#          VSTEST_ARGS="$VSTEST_ARGS /TestCaseFilter:$CATEGORY_FILTER"
#          shift
#          shift ;;
#      -testnames|-testname)
#          VSTEST_ARGS="$VSTEST_ARGS /Tests:$2"
#          shift
#          shift ;;
#      -unattended)
#          export Unattended=True
#          shift ;;
#      -verbose)
#          VERBOSE_MODE=TRUE
#          shift ;;
      -?) Usage
          shift ;;
      *)  if [ "$1" != "${1#-}" ] ; then
             Usage "Invalid argument $1"
          else
             if [ "$TEST_CSPROJ_LIST" = "" ] ; then
                TEST_CSPROJ_LIST="$1"
             else
                TEST_CSPROJ_LIST="$TEST_CSPROJ_LIST,$1"
             fi
          fi
          shift ;;
   esac
done

if [ "$TEST_CSPROJ_LIST" = "" ] ; then
   TEST_CSPROJ_LIST=`find . -name *Test.csproj -print`
fi

if [ "$TEST_CSPROJ_LIST" = "" ] ; then
   Usage "Must specify at least one test csproj file."
fi

UNIT_TEST_BASE_FILE_NAME="UnitTestOutput.$$"
UNIT_TEST_OUTPUT_FILE="$TMP/$UNIT_TEST_BASE_FILE_NAME"
#VSTEST_OUTPUT_FILE="$TMP/VSTestOutput.$$"
#VSTEST_ERROR_FILE="$TMP/VSTestError.$$"
#export UNIT_TEST_OUTPUT_FILE_NAME="$(EZPath2Win $UNIT_TEST_OUTPUT_FILE)"
#
#if [ "$CODE_COVERAGE" = TRUE ] ; then
#   rm -rf TestResults
#fi

EXIT_CODE=0
for SINGLE_TEST_CSPROJ in $TEST_CSPROJ_LIST
do
   EZRun dotnet test $SINGLE_TEST_CSPROJ --no-build --no-restore --verbosity normal | \
         sed -e 's/
//g'                                        \
             -e '/^$/d'                                          \
             -e '/^Build started /d'                             \
             -e '/^Build succeeded.$/d'                          \
             -e '/^Copyright (c) /d'                             \
             -e '/^Microsoft (R) /d'                             \
             -e '/^Starting test execution, /d'                  \
             -e '/^Standard Output Messages:$/d'                 \
             -e '/^Test run for /d'                              \
             -e '/^Test Run Successful.$/d'                      \
             -e '/^Test execution time: /d'                      \
             -e '/^Time Elapsed /d'                              \
             -e '/^Total tests: /d'                              \
             -e '/^    0 Error(s)$/d'                            \
             -e '/^    0 Warning(s)$/d'                          \
             -e 's/^Passed   /Successfully passed /'             \
             -e 's/^ Successfully passed /Successfully passed /' \
             -e '/This is the main for C4Core./d'                \
             | tee "$UNIT_TEST_OUTPUT_FILE"


#   if [ "$EZ_DRYRUN" = TRUE ] ; then
#      echo "export UNIT_TEST_OUTPUT_FILE_NAME='$UNIT_TEST_OUTPUT_FILE_NAME'"
#      echo "vstest.console $VSTEST_ARGS $SINGLE_TEST_DLL"
#      echo "cat '$UNIT_TEST_OUTPUT_FILE_NAME'"
#   else
#      touch "$UNIT_TEST_OUTPUT_FILE_NAME"
#      # In CYGWIN 1.7.24 the command line for tail and other processes
#      # does not contain the actual command line arguments.
#      # For this reason, we need to create our unique instance of tail.exe
#      # so we can be sure that we kill only our instance.
#      TAIL_EXE="tail.$$.exe"
#      TAIL_FULL_NAME="$TMP/$TAIL_EXE"
#      if [ "$VERBOSE_MODE" = TRUE ] ; then
#         echo -n "vstest.console $VSTEST_ARGS $SINGLE_TEST_DLL "
#         echo    "> $VSTEST_OUTPUT_FILE"
#      fi
#      cp /usr/bin/tail.exe "$TAIL_FULL_NAME"
#      ( $TAIL_FULL_NAME -f "$UNIT_TEST_OUTPUT_FILE_NAME" 2>&1 | \
#        egrep -v "$UNIT_TEST_BASE_FILE_NAME: file truncated" ) &
#      vstest.console $VSTEST_ARGS $SINGLE_TEST_DLL > "$VSTEST_OUTPUT_FILE" 2>&1
#      VSTEST_EXIT_CODE=$?
#      if [ "$VSTEST_EXIT_CODE" -ne 0 ] ; then
#         EXIT_CODE=$VSTEST_EXIT_CODE
#      fi
#
#      C4.sh ProcessStatus -Text $TAIL_EXE -NotMyPid -Kill ALL -Silent
#      rm -f "$TAIL_FULL_NAME"
#      STACK_TRACE_TEXT="XYZXYZXYZ" 
#      if [ "$STACK_TRACE" = TRUE ] ; then
#         STACK_TRACE_TEXT="^    at |^   at|^Stack Trace:\$|^ --- End of inner|^Error Message:\$"
#      fi
#      egrep "threw exception:|^Warning: |$STACK_TRACE_TEXT|^[ -~]*Exception: |^ ---> |^   Test method |^TechnologyName: |^Name: |^ControlType: |^Failed |^Microsoft.VisualStudio.TestTools.UITest" \
#            "$VSTEST_OUTPUT_FILE" | egrep -v "$ALLOWED_ERROR_MESSAGE" \
#          > "$VSTEST_ERROR_FILE"
#      cat "$VSTEST_ERROR_FILE"
#      cat "$VSTEST_ERROR_FILE" >> "$UNIT_TEST_OUTPUT_FILE_NAME"
#   fi
done

#echo "Exiting Early..."
#exit 1

#if [ "$CAT_FILE_FULL_NAME" != "" ] ; then
#   cat "$CAT_FILE_FULL_NAME"
#fi

#if [ "$EZ_DRYRUN" != TRUE -a "$CODE_COVERAGE" = TRUE ] ; then
#   if [ -d "$EZ_CODE_COVERAGE_ROOT" ] ; then
#      COVERAGE_FILE=`dlook.sh '*.coverage'`
#      if [ "$MASTER_FILE_NAME" = "" ] ; then
#         TEST_DIR_NAME="${PWD##*/}" 
#         MASTER_FILE_NAME="$TEST_DIR_NAME.coverage"
#      fi
#      MASTER_FILE_FULE_NAME="$EZ_CODE_COVERAGE_ROOT/$MASTER_FILE_NAME"
#      cp "$COVERAGE_FILE" "$MASTER_FILE_FULE_NAME"
#      chmod 777           "$MASTER_FILE_FULE_NAME"
#      if [ "$QUIET_MODE" != TRUE ] ; then
#         echo "Successfully created $MASTER_FILE_FULE_NAME."
#      fi
#      if [ "$STATS_MODE" = TRUE ] ; then
#         echo
#         C4.sh -Coverage Stats -f $MASTER_FILE_FULE_NAME
#      fi
#   fi
#fi

if [ "$EZ_DRYRUN" = TRUE ] ; then
   exit 0
fi

if [ -f "$UNIT_TEST_OUTPUT_FILE" -a "$SHOW_SUMMARY" != FALSE ] ; then
   UNIT_TEST_FAIL_FILE="$TMP/RunTestErr.$$"
   egrep -v "Successfully passed" "$UNIT_TEST_OUTPUT_FILE" \
                                > "$UNIT_TEST_FAIL_FILE"
   TOTAL_FAILS=`wc -l "$UNIT_TEST_FAIL_FILE" | awk '{ print $1 }'`
   if [ "$TOTAL_FAILS" != 0 ] ; then
      echo
      echo -n "Warning: Would you like to see the $TOTAL_FAILS "
      echo -n "unsuccessful tests? "
      typeset -u ANSWER
      read ANSWER
      if [ "$ANSWER" = Y ] ; then
         echo
         echo
         cat "$UNIT_TEST_FAIL_FILE"
      fi
   fi
fi

if [ "$RESULTS_FILE_NAME" != "" ] ; then
   cp "$UNIT_TEST_OUTPUT_FILE" "$RESULTS_FILE_NAME"
fi

rm -f "$VSTEST_OUTPUT_FILE" "$VSTEST_ERROR_FILE"
rm -f "$UNIT_TEST_OUTPUT_FILE" "$UNIT_TEST_FAIL_FILE"

exit $EXIT_CODE
