#===========================================================================
#  FileName: TestParsers.ksh
#    Author: Craig Schneider
# Orig Date: 10/22/13
# Copyright: ShadowScape Technologies, Inc. (see copyright file for details)
#  Synopsis: Verify the Parsers.
#===========================================================================

. $EZ_SHARED_ENV
. ${EZ_VERIFY_ROOT-.}/VerifyFunctions.ksh $0

CREATE_MODE=FALSE
DIFF_FILES_ARGS=
EZ_DRYRUN=FALSE
EZ_VERBOSITY=
FEED_NAME_FILTER="*"
FILE_NAME_FILTER="*"
FILE_LIMIT=99999
FILE_PARSER_ARGS=
CONSOLE_STATUS_ARG="-NoConsoleStatus"
INPUT_DIR_NAME="Input"
NEW_ID_CHILD_1=FALSE
PERFORM_MD5_HASH=TRUE
RANDOM_INCLUDES_0001=TRUE
RANDOM_ORDER=FALSE
RENAME_MODE=FALSE
RENAME_INDEX=1
SEVENZ_MODE=FALSE
STABLE_NAME_FILTER="Stable*"
STABALIZE=FALSE
STABALIZE_ARGS=
STABALIZE_JSON_STATUS_ARGS=
STATS_MODE=FALSE
STOP_ON_DIFF=FALSE
STOP_FEEDS_ON_ERROR=TRUE
STOP_FILES_ON_ERROR=TRUE
TOTAL_FEEDS=0
TOTAL_FILES_PARSED=0

ROOT_DIRECTORY="C:/FileParserTest"
if [ ! -d "$ROOT_DIRECTORY" -a -d "D:/FileParserTest" ] ; then
   ROOT_DIRECTORY="D:/FileParserTest"   
fi

#===========================================================================
# Display the usage.
#===========================================================================
function Usage
{
   if [ "$1" != "" ] ; then
      echo
      echo $*
   fi
   cat <<!

Usage: TestParsers [-7z] [-Args FileParserArgs] [-Cat] [-ColDiffs] [-Create]
                   [-Diffs] [-DryRun] [-Feed FeedNameFilter]
                   [-File FileNameFilter] [-FileLimit] [-Input InputDirName]
                   [-NewIdChild1] [-NoMD5] [-NoPerfStats]
                   [-NoSevenZipStream] [-NoStopOnError] [-Performance]
                   [-RandomOrder] [-Rename] [-RenameIndex Index]
                   [-Root RootDirectory] [-s ServerName] [SevenZipStream]
                   [-Stabalize] [-Stable StableNameFilter] [-StopOnDiff]
                   [-StopFeedsOnError] [-StopFilesOnError] [-Update]
                   [-Quiet | -Verbose] [-Yes] [-YesJsonStatus]

              -7z: Create .7z versions of the input files.
            -Args: Additional arguments to pass to the FileParser.
             -Cat: Cat the content of the column files with differences.
    -CodeCoverage: Specifies that code coverage results are produced.
        -ColDiffs: Display the differences in content of the columns.
          -Create: Specifies that creation of stable files is allowed.
           -Diffs: Display the differences when files do not match.
          -DryRun: Display the commands to be executed, without executing them.
            -Feed: The feed name filter to use (default *).
            -File: The file name filter to use (default *).
       -FileLimit: Specifes the number of files to run per Stable directory.
           -Input: The name of the input directory (default Input).
     -NewIdChild1: Create a new InFileIdChild1 if needed.
           -NoMD5: Do not perform the MD5 hash generation or validation.
     -NoPerfStats: Performance stats are not written to the event log.
   -NoStopOnError: Do not stop processing files or feeds on the first error.
-NoSevenZipStream: Specifies that the SevenZipExtractStream is not preferred.
     -Performance: Display performance numbers to the console.
     -RandomOrder: Specifies that the files be parsed in a random order.
          -Rename: Specifies the files be renamed to shorter names.
     -RenameIndex: Specifies the index number to start at when renaming files.
            -Root: The root directory (default $ROOT_DIRECTORY).
               -s: ServerName of the database server to connect to.
  -SevenZipStream: Specifies that the SevenZipExtractStream is preferred.
       -Stabalize: Allow stabalizing from the ouptut file.
          -Stable: The stable directory filter to use (default Stable*).
           -Stats: Display the CodeCoverage Stats for this run.
      -StopOnDiff: Stop showing column diffs after the first column difference.
-StopFeedsOnError: Stop processing the feeds on the first error.
-StopFilesOnError: Stop processing the files of a feed on the first error.
 -StopRecordCount: The number of records to process before stopping.
           -Quiet: Suppress non critical messages about operations performed.
          -Update: Specifies that updating of stable files is allowed.
         -Verbose: Display verbose messages about operations being performed.
             -Yes: All user questions will be implicitly answered with a yes.
   -YesJsonStatus: Answer yes to stabalizing of the json status files.

!
   exit 1
}

#===========================================================================
# Process the command line arguments.
#===========================================================================
if [ "$1" = "-?" ] ; then
   Usage
fi

typeset -l LOWERCASE_ARG
while [ $# -ne 0 ]
do
   LOWERCASE_ARG="$1"
   case $LOWERCASE_ARG in
         -7z) SEVENZ_MODE=TRUE
              shift ;;
       -args) FILE_PARSER_ARGS="$FILE_PARSER_ARGS $2"
              shift
              shift ;;
        -cat) DIFF_FILES_ARGS="$DIFF_FILES_ARGS $1"
              shift ;;
-codecoverage) CODE_COVERAGE_EXE="CodeCoverage.ksh"
              shift ;;
   -coldiffs) DIFF_FILES_ARGS="$DIFF_FILES_ARGS -diffs"
              shift ;;
     -create) CREATE_MODE=TRUE
              STABALIZE=TRUE
              shift ;;
      -diffs) STABALIZE_ARGS="$STABALIZE_ARGS $1"
              shift ;;
     -dryrun) EZ_DRYRUN=TRUE
              shift ;;
       -file) FILE_NAME_FILTER="$2"
              shift
              shift ;;
  -filelimit) FILE_LIMIT="$2"
              shift
              shift ;;
       -feed) FEED_NAME_FILTER="$2"
              shift
              shift ;;
      -input) INPUT_DIR_NAME="$2"
              shift
              shift ;;
-newidchild1) NEW_ID_CHILD_1=TRUE
              shift ;;
      -nomd5) PERFORM_MD5_HASH=FALSE
              shift ;;
-noperfstats) FILE_PARSER_ARGS="$FILE_PARSER_ARGS -NoPerfStats"
              shift ;;
-nosevenzipstream) FILE_PARSER_ARGS="$FILE_PARSER_ARGS -NoSevenZipStream"
              shift ;;
-nostoponerror) STOP_FEEDS_ON_ERROR=FALSE
                STOP_FILES_ON_ERROR=FALSE
              shift ;;
-performance|-perf) CONSOLE_STATUS_ARG="-Performance"
              shift ;;
       -quiet|-verbose)
              EZ_VERBOSITY="${LOWERCASE_ARG#-}"
              shift ;;
-randomorder|-random) RANDOM_ORDER=TRUE
              shift ;;
     -rename) RENAME_MODE=TRUE
              shift ;;
-renameindex) RENAME_INDEX="$2"
              shift
              shift ;;
       -root) ROOT_DIRECTORY="$2"
              shift
              shift ;;
          -s) FILE_PARSER_ARGS="$FILE_PARSER_ARGS -s $2"
              shift
              shift ;;
-sevenzipstream) FILE_PARSER_ARGS="$FILE_PARSER_ARGS -SevenZipStream"
              shift ;;
  -stabalize) STABALIZE=TRUE
              shift ;;
     -stable) STABLE_NAME_FILTER="$2"
              shift
              shift ;;
      -stats) STATS_MODE=TRUE
              shift ;;
 -stopondiff) DIFF_FILES_ARGS="$DIFF_FILES_ARGS $1"
              shift ;;
-stopfeedsonerror) STOP_FEEDS_ON_ERROR=TRUE
              shift ;;
-stopfilesonerror) STOP_FILES_ON_ERROR=TRUE
              shift ;;
-stoprecordcount)
              FILE_PARSER_ARGS="$FILE_PARSER_ARGS $1 $2"
              DIFF_FILES_ARGS="$DIFF_FILES_ARGS -Head $2"
              shift
              shift ;;
     -update) STABALIZE=TRUE
              shift ;;
        -yes) STABALIZE_ARGS="$STABALIZE_ARGS $1"
              shift ;;
-yesjsonstatus) STABALIZE_JSON_STATUS_ARGS="$STABALIZE_JSON_STATUS_ARGS -yes"
              shift ;;
           *) if [ "$1" != "-?" ] ; then
                 Usage "Invalid argument: $1"
              else
                 Usage
              fi ;;
    esac
done

if [ "$PERFORM_MD5_HASH" = TRUE ] ; then
   FILE_PARSER_ARGS="$FILE_PARSER_ARGS -MD5Hash"
fi

if [ ! -d "$ROOT_DIRECTORY" ] ; then
   echo "ERROR: Failed to find root directory $ROOT_DIRECTORY."
   exit 1
fi
cd "$ROOT_DIRECTORY"

EXIT_CODE=0

#===========================================================================
# Cleanup any spurious files left hanging around.
# NOTE: A copy of this function exists in src_out.ksh and TestParsers.ksh
#===========================================================================
function PerformSpuriousFileCleanup
{
   FIRST_FILE=FALSE
   for SPURIOUS_FILE in `dlook.sh '*.exe.stackdump'`
   do
      if [ "$FIRST_FILE" = FALSE ] ; then
         echo
         echo "Successfully removing spurious files..."
         FIRST_FILE=TRUE
      fi
      rm -f "$SPURIOUS_FILE"
      echo "Successfully removed $SPURIOUS_FILE."
   done
}

function VerifySingleFile
{
   STABLE_TEMP="${FEED_STABLE_FULL_FILE%.txt}"
   IN_FILE_ID="${STABLE_TEMP##*.}"
   FEED_OUTPUT_FILE="${FEED_STABLE_FULL_FILE##*/}"
   FEED_OUTPUT_CHILD1_FILE="$FEED_OUTPUT_FILE.child1"
   FEED_OUTPUT_JSON_STATUS_FILE="$FEED_OUTPUT_FILE.status.json"
   FEED_OUTPUT_FULL_FILE="$FEED_TEMP_FULL_DIR/$FEED_OUTPUT_FILE"
   FEED_OUTPUT_CHILD1_FULL_FILE="$FEED_OUTPUT_FULL_FILE.child1"
   FEED_OUTPUT_JSON_STATUS_FULL_FILE="$FEED_OUTPUT_FULL_FILE.status.json"
   FEED_STABLE_CHILD1_FULL_FILE="$FEED_STABLE_FULL_FILE.child1"
   FEED_STABLE_JSON_STATUS_FULL_FILE="$FEED_STABLE_FULL_FILE.status.json"
   TEST_SETTINGS_FULL_FILE="$FEED_STABLE_FULL_DIR/TestSettings.ksh"
   IN_FILE_ID_CHILD_1=
   if [ -f "$FEED_STABLE_JSON_STATUS_FULL_FILE" ] ; then
      IN_FILE_ID_CHILD_1=`grep InFileIdChild1 \
           "$FEED_STABLE_JSON_STATUS_FULL_FILE" | cut -f2 -d: | sed 's/,//'`
   fi
   FEED_INPUT_FILE_NAME="${FEED_INPUT_FULL_FILE##*/}"
   
   #echo "FEED_NAME=$FEED_NAME"
   #echo "FEED_INPUT_FULL_FILE=$FEED_INPUT_FULL_FILE"
   #echo "FEED_STABLE_FULL_FILE=$FEED_STABLE_FULL_FILE"
   #echo "FEED_OUTPUT_FULL_FILE=$FEED_OUTPUT_FULL_FILE"
   #echo "FEED_TEMP_FULL_DIR=$FEED_TEMP_FULL_DIR"
   #echo "IN_FILE_ID=$IN_FILE_ID"

   rm -rf "$FEED_TEMP_FULL_DIR"
   mkdir "$FEED_TEMP_FULL_DIR"

   DIFF_FILES_CUST_ARGS=
   FILE_PARSER_CUST_ARGS=
   DEFINITION_FILE_NAME=
   FIELD_SEPARATOR=
   INPUT_FORMAT_NAME=
   NO_HEADERS=
   SPECIAL_FIELDS=
   QUIET_MODE=
   if [ -f "$TEST_SETTINGS_FULL_FILE" ] ; then
      . "$TEST_SETTINGS_FULL_FILE"
   fi
   if [ "$NO_HEADERS" != TRUE ] ; then
      FILE_PARSER_CUST_ARGS="$FILE_PARSER_CUST_ARGS -IncludeHeaders"
   fi
   if [ "$SPECIAL_FIELDS" != TRUE ] ; then
      FILE_PARSER_CUST_ARGS="$FILE_PARSER_CUST_ARGS -NoSpecialFields"
   fi
   if [ "$QUIET_MODE" = TRUE ] ; then
      FILE_PARSER_CUST_ARGS="$FILE_PARSER_CUST_ARGS -Quiet"
   fi
   if [ "$DEFINITION_FILE_NAME" != "" ] ; then
      FILE_PARSER_CUST_ARGS="$FILE_PARSER_CUST_ARGS -def $DEFINITION_FILE_NAME"
   fi
   if [ "$FIELD_SEPARATOR" != "" ] ; then
      FILE_PARSER_CUST_ARGS="$FILE_PARSER_CUST_ARGS -FieldSeparator $FIELD_SEPARATOR"
      DIFF_FILES_CUST_ARGS="$DIFF_FILES_CUST_ARGS -ColSeparator $FIELD_SEPARATOR"
   fi
   if [ "$IN_FILE_ID_CHILD_1" = "" -a "$NEW_ID_CHILD_1" = TRUE ] ; then
      IN_FILE_ID_CHILD_1=`C4 GetGUID -int`
   fi
   if [ "$IN_FILE_ID_CHILD_1" != "" ] ; then
      FILE_PARSER_CUST_ARGS="$FILE_PARSER_CUST_ARGS -InFileIdChild1 $IN_FILE_ID_CHILD_1"
   fi
   if [ "$INPUT_FORMAT_NAME" = "" ] ; then
      INPUT_FORMAT_NAME="$FEED_NAME"
   fi
   INPUT_FORMAT_NAME_ARGS="-InputFormatName $INPUT_FORMAT_NAME"

   CODE_COVERAGE_CMD="$CODE_COVERAGE_EXE"
   if [ "$CODE_COVERAGE_CMD" != "" ] ; then
      CODE_COVERAGE_CMD="$CODE_COVERAGE_EXE -MasterFileName FileParser.$FEED_NAME.$FEED_FILE_BASE.coverage"
      if [ "$STATS_MODE" = TRUE ] ; then
         CODE_COVERAGE_CMD="$CODE_COVERAGE_CMD -Stats"
      fi
   fi
   FILE_PARSER_EXE=`whence FileParser.exe`
   FILE_PARSER_EXE_WIN=`EZPath2Win $FILE_PARSER_EXE`
   EZInvokeCommand $CODE_COVERAGE_CMD $FILE_PARSER_EXE_WIN -n $FEED_NAME \
           $INPUT_FORMAT_NAME_ARGS -InFileId $IN_FILE_ID \
           -i $FEED_INPUT_FULL_FILE \
           $FILE_PARSER_ARGS $FILE_PARSER_CUST_ARGS \
           -OutputDirectory $FEED_TEMP_FULL_DIR $CONSOLE_STATUS_ARG \
           -JsonStatus -StableOutput
   PARSER_EXIT=$?
   if [ "$PARSER_EXIT" -ne 0 ] ; then
      echo "ERROR: The FileParser failed with exit code $PARSER_EXIT."
      echo "ERROR: Check the directory $FEED_TEMP_FULL_DIR for details."
      EXIT_CODE=1
      return 1
   else
      VerifyPassed "$FEED_INPUT_FILE_NAME was parsed."
   fi
   if [ "$EZ_DRYRUN" = TRUE ] ; then
      if [ "$STABALIZE" = TRUE ] ; then
         echo "Would execute: src.ksh stabalize $STABALIZE_ARGS $FEED_OUTPUT_FULL_FILE $FEED_STABLE_FULL_FILE"
      else
         echo "Would execute: DiffFiles.ksh -quiet -ColDataDir $COL_DATA_DIR -Tmp "$FEED_TEMP_FULL_DIR" $DIFF_FILES_ARGS $DIFF_FILES_CUST_ARGS $FEED_OUTPUT_FULL_FILE $FEED_STABLE_FULL_FILE"
      fi
   else
      if [ ! -f "$FEED_OUTPUT_FULL_FILE" ] ; then
         echo -n "ERROR: The FileParser did not create file \c"
         echo    "$FEED_OUTPUT_FULL_FILE."
         EXIT_CODE=1
         return 1
      fi
   
      COL_DATA_DIR="$FEED_TEMP_FULL_DIR/ColData"
      DIFF_FILES_MESSAGE=TRUE
      if [ ! -f "$FEED_STABLE_FULL_FILE" -a "$CREATE_MODE" = TRUE ] ; then
         DIFF_FILES_MESSAGE=FALSE
         DIFF_FILES_EXIT=1
      else
         DiffFiles.ksh -quiet -ColDataDir "$COL_DATA_DIR" \
                       -Tmp "$FEED_TEMP_FULL_DIR" \
                       $DIFF_FILES_ARGS $DIFF_FILES_CUST_ARGS \
                       "$FEED_OUTPUT_FULL_FILE" "$FEED_STABLE_FULL_FILE"
         DIFF_FILES_EXIT=$?
      fi
      if [ "$DIFF_FILES_EXIT" != 0 ] ; then
         if [ "$DIFF_FILES_MESSAGE" = TRUE ] ; then
            echo "ERROR: DiffFiles.ksh detected differences in output file"
            echo "ERROR: $FEED_OUTPUT_FULL_FILE."
            echo "ERROR: Check the directory $COL_DATA_DIR for details."
         fi

         if [ "$STABALIZE" = TRUE ] ; then
            src.ksh stabalize $STABALIZE_ARGS "$FEED_OUTPUT_FULL_FILE" "$FEED_STABLE_FULL_FILE"
         else
            EXIT_CODE=1
            return 1
         fi
      else
         VerifyPassed "$FEED_OUTPUT_FILE is identical."
      fi

      # CHILD1
      if [ -f "$FEED_OUTPUT_CHILD1_FULL_FILE" ] ; then
         COL_DATA_DIR="$FEED_TEMP_FULL_DIR/ColData"
         DIFF_FILES_MESSAGE=TRUE
         if [ ! -f "$FEED_STABLE_CHILD1_FULL_FILE" -a \
              "$CREATE_MODE" = TRUE ] ; then
            DIFF_FILES_MESSAGE=FALSE
            DIFF_FILES_EXIT=1
         else
            DiffFiles.ksh -quiet -ColDataDir "$COL_DATA_DIR" \
                          -Tmp "$FEED_TEMP_FULL_DIR" \
                          $DIFF_FILES_ARGS $DIFF_FILES_CUST_ARGS \
                          "$FEED_OUTPUT_CHILD1_FULL_FILE" \
                          "$FEED_STABLE_CHILD1_FULL_FILE"
            DIFF_FILES_EXIT=$?
         fi
         if [ "$DIFF_FILES_EXIT" != 0 ] ; then
            if [ "$DIFF_FILES_MESSAGE" = TRUE ] ; then
               echo "ERROR: DiffFiles.ksh detected differences in output file"
               echo "ERROR: $FEED_OUTPUT_CHILD1_FULL_FILE."
               echo "ERROR: Check the directory $COL_DATA_DIR for details."
            fi
            if [ "$STABALIZE" = TRUE ] ; then
               src.ksh stabalize $STABALIZE_ARGS "$FEED_OUTPUT_CHILD1_FULL_FILE" "$FEED_STABLE_CHILD1_FULL_FILE"
            else
               EXIT_CODE=1
               return 1
            fi
         else
            VerifyPassed "$FEED_OUTPUT_CHILD1_FILE is identical."
         fi
      fi

      # JSON_STATUS
      if [ -f "$FEED_OUTPUT_JSON_STATUS_FULL_FILE" ] ; then
         src.ksh stabalize -diffs $STABALIZE_ARGS $STABALIZE_JSON_STATUS_ARGS \
-t Unchanged "Successfully passed $FEED_OUTPUT_JSON_STATUS_FILE is identical." \
   "$FEED_OUTPUT_JSON_STATUS_FULL_FILE" "$FEED_STABLE_JSON_STATUS_FULL_FILE"

         PARSE_BYTES_READ=`grep ParseBytesRead \
                "$FEED_OUTPUT_JSON_STATUS_FULL_FILE" | \
                 cut -f 2 -d: | cut -f 1 -d,`
         if [ "$PARSE_BYTES_READ" = "" ] ; then
            sleep 3  # sometimes the file content is not synced yet.
            PARSE_BYTES_READ=`grep ParseBytesRead \
                "$FEED_OUTPUT_JSON_STATUS_FULL_FILE" | \
                 cut -f 2 -d: | cut -f 1 -d,`
         fi
         if [ "$PARSE_BYTES_READ" = "" ] ; then
            echo "ERROR: Failed to find ParseBytesRead in \c"
            echo "the json status file \c"
            echo "$FEED_OUTPUT_JSON_STATUS_FULL_FILE."
         else
            FEED_INPUT_FILE_EXT="${FEED_INPUT_FULL_FILE##*.}"
            if [ "$FEED_INPUT_FILE_EXT" = "7z" -o \
                 "$FEED_INPUT_FILE_EXT" = "gz" -o \
                 "$FEED_INPUT_FILE_EXT" = "gzip" -o \
                 "$FEED_INPUT_FILE_EXT" = "tar" -o \
                 "$FEED_INPUT_FILE_EXT" = "xz" -o \
                 "$FEED_INPUT_FILE_EXT" = "zip" ] ; then
               if [ "$EZ_VERBOSITY" = "verbose" ] ; then
                  echo "7z t $FEED_INPUT_FULL_FILE"
               fi
               FEED_INPUT_FILE_SIZE=`7z t "$FEED_INPUT_FULL_FILE" | \
                                     egrep '^Size:' | awk '{print $2}'`
            elif [ "$FEED_INPUT_FILE_EXT" = "bz2" -o \
                   "$FEED_INPUT_FILE_EXT" = "bzip2" ] ; then
               7z x -so "$FEED_INPUT_FULL_FILE" > $TMPDIR/tp_bz2.dat \
                                                2>$EZ_DEV_NULL
               FEED_INPUT_FILE_SIZE=`ls -l "$TMPDIR/tp_bz2.dat" | \
                                     sed 's/Domain Users/DomainUsers/' | \
                                     awk '{print $5}'`
               rm -f $TMPDIR/tp_bz2.dat
            else
               FEED_INPUT_FILE_SIZE=`ls -l "$FEED_INPUT_FULL_FILE" | \
                                     sed 's/Domain Users/DomainUsers/' | \
                                     awk '{print $5}'`
            fi
            if [ "$PARSE_BYTES_READ" != "$FEED_INPUT_FILE_SIZE" ] ; then
               echo "ERROR: ParseBytesRead $PARSE_BYTES_READ does \c"
               echo "not match the file size of $FEED_INPUT_FILE_SIZE for \c"
               echo "file $FEED_INPUT_FULL_FILE."
               EXIT_CODE=1
               return 1
            else
               echo "Successfully passed $FEED_OUTPUT_FILE bytes read \c"
               echo "$FEED_INPUT_FILE_SIZE."
            fi
         fi

         PARSE_BYTES_WRITTEN=`grep ParseBytesWritten \
                "$FEED_OUTPUT_JSON_STATUS_FULL_FILE" | \
                 cut -f 2 -d: | cut -f 1 -d,`
         if [ "$PARSE_BYTES_WRITTEN" = "" ] ; then
            echo "ERROR: Failed to find ParseBytesWritten in \c"
            echo "the json status file \c"
            echo "$FEED_OUTPUT_JSON_STATUS_FULL_FILE."
            EXIT_CODE=1
            return 1
         else
            FEED_OUTPUT_FILE_SIZE=`ls -l "$FEED_OUTPUT_FULL_FILE" | \
                                   sed 's/Domain Users/DomainUsers/' | \
                                   awk '{print $5}'`
            if [ "$PARSE_BYTES_WRITTEN" != "$FEED_OUTPUT_FILE_SIZE" ] ; then
               echo "ERROR: ParseBytesWritten $PARSE_BYTES_WRITTEN does \c"
               echo "not match the file size of $FEED_OUTPUT_FILE_SIZE for \c"
               echo "file $FEED_OUTPUT_FULL_FILE."
               EXIT_CODE=1
               return 1
            else
               echo "Successfully passed $FEED_OUTPUT_FILE bytes written \c"
               echo "$FEED_OUTPUT_FILE_SIZE."
            fi
         fi

         MD5_HASH=`grep ParseMD5Hash \
                "$FEED_OUTPUT_JSON_STATUS_FULL_FILE" | \
                 cut -f 2 -d: | cut -f 1 -d, | sed 's/"//g'`
         if [ "$MD5_HASH" = "" ] ; then
            if [ "$PERFORM_MD5_HASH" = TRUE ] ; then
               echo "ERROR: Failed to find ParseMD5Hash in \c"
               echo "the json status file \c"
               echo "$FEED_OUTPUT_JSON_STATUS_FULL_FILE."
               EXIT_CODE=1
               return 1
            fi
         else
            MD5_TMP="$TMPDIR/MD5.sum.$$"
            rm -rf "$MD5_TMP"
            mkdir "$MD5_TMP"
            MD5_TMP_WIN=`EZPath2Win "$MD5_TMP"`
            MD5_SUM_FILE_NAME="$FEED_INPUT_FULL_FILE"
            if [ "$FEED_INPUT_FILE" != "$FEED_FILE_BASE" ] ; then
               7z x -o"$MD5_TMP_WIN" $FEED_INPUT_FULL_FILE > /dev/null
               MD5_SUM_FILE_NAME="$MD5_TMP/$FEED_FILE_BASE"
               if [ ! -f "$MD5_SUM_FILE_NAME" ] ; then
                  MD5_SUM_FILE_NAME=`ls $MD5_TMP/*`
               fi
            fi
            MD5_SUM=`md5sum "$MD5_SUM_FILE_NAME" | cut -f1 -d' '` 
            rm -rf "$MD5_TMP"
            if [ "$MD5_HASH" != "$MD5_SUM" ] ; then
               echo "ERROR: MD5Hash $MD5_HASH does \c"
               echo "not match the md5sum of $MD5_SUM for \c"
               echo "file $FEED_INPUT_FULL_FILE."
               EXIT_CODE=1
               return 1
            else
               echo "Successfully passed $FEED_OUTPUT_FILE MD5 \c"
               echo "$MD5_HASH."
            fi
         fi
      else
         echo "ERROR: Failed to create json status file \c"
         echo "$FEED_OUTPUT_JSON_STATUS_FULL_FILE."
         EXIT_CODE=1
         return 1
      fi
   fi

   if [ "$RENAME_MODE" = TRUE ] ; then
      EXTENSION="${FEED_INPUT_FULL_FILE##*.}"
      EXT_TXT=
      if [ "$EXTENSION" = "7z"    -o \
           "$EXTENSION" = "bz2"   -o \
           "$EXTENSION" = "bzip2" -o \
           "$EXTENSION" = "gz"    -o \
           "$EXTENSION" = "gzip"  -o \
           "$EXTENSION" = "tar"   -o \
           "$EXTENSION" = "xz"    -o \
           "$EXTENSION" = "zip" ] ; then
         EXT_TXT=".$EXTENSION"
      fi
      typeset -RZ4 RENAME_INDEX_FMT
      RENAME_INDEX_FMT="$RENAME_INDEX"
      NEW_INPUT_FILE="$FEED_NAME.$RENAME_INDEX_FMT$EXT_TXT"
      NEW_INPUT_FULL_FILE="$FEED_INPUT_FULL_DIR/$NEW_INPUT_FILE"
      NEW_STABLE_FILE="$FEED_NAME.$RENAME_INDEX_FMT.$IN_FILE_ID.txt"
      NEW_STABLE_FULL_FILE="$FEED_STABLE_FULL_DIR/$NEW_STABLE_FILE"
      NEW_STABLE_CHILD1_FULL_FILE="$NEW_STABLE_FULL_FILE.child1"
      NEW_STABLE_JSON_STATUS_FULL_FILE="$NEW_STABLE_FULL_FILE.status.json"
      if [ "$FEED_STABLE_FULL_FILE" = "$NEW_STABLE_FULL_FILE" ] ; then
         echo "Warning: Not renaming since already named $NEW_STABLE_FILE."
         let RENAME_INDEX=RENAME_INDEX+1
         let TOTAL_FILES_PARSED=TOTAL_FILES_PARSED+1
         return 0
      fi
      if [ -f "$NEW_INPUT_FULL_FILE" ] ; then
         echo -n "ERROR: The renamed input file $NEW_INPUT_FULL_FILE \c"
         echo    "already exists."
         EXIT_CODE=1
         return 1
      fi
      if [ -f "$NEW_STABLE_FULL_FILE" ] ; then
         echo -n "ERROR: The renamed stable file $NEW_STABLE_FULL_FILE \c"
         echo    "already exists."
         EXIT_CODE=1
         return 1
      fi

      if [ "$EZ_DRYRUN" = TRUE ] ; then
         echo
         echo "Would rename..."
         echo "From: $FEED_INPUT_FULL_FILE" 
         echo "  To: $NEW_INPUT_FULL_FILE" 
         echo
         echo "Would rename..."
         echo "From: $FEED_STABLE_FULL_FILE" 
         echo "  To: $NEW_STABLE_FULL_FILE" 
         echo
         if [ -f "$FEED_STABLE_CHILD1_FULL_FILE" ] ; then
            echo
            echo "Would rename..."
            echo "From: $FEED_STABLE_CHILD1_FULL_FILE" 
            echo "  To: $NEW_STABLE_CHILD1_FULL_FILE" 
            echo
         fi
         if [ -f "$FEED_STABLE_JSON_STATUS_FULL_FILE" ] ; then
            echo
            echo "Would rename..."
            echo "From: $FEED_STABLE_JSON_STATUS_FULL_FILE" 
            echo "  To: $NEW_STABLE_JSON_STATUS_FULL_FILE" 
            echo
         fi
      else
         mv      "$FEED_INPUT_FULL_FILE"  \
                  "$NEW_INPUT_FULL_FILE"
         mv      "$FEED_STABLE_FULL_FILE" \
                  "$NEW_STABLE_FULL_FILE"
         if [ -f "$FEED_STABLE_CHILD1_FULL_FILE" ] ; then
              mv "$FEED_STABLE_CHILD1_FULL_FILE" \
                  "$NEW_STABLE_CHILD1_FULL_FILE"
         fi
         if [ -f "$FEED_STABLE_JSON_STATUS_FULL_FILE" ] ; then
            mv   "$FEED_STABLE_JSON_STATUS_FULL_FILE" \
                  "$NEW_STABLE_JSON_STATUS_FULL_FILE"
         fi
         echo "Successfully renamed to $NEW_STABLE_FILE."
      fi
      let RENAME_INDEX=RENAME_INDEX+1
   fi
   if [ "$SEVENZ_MODE" = TRUE ] ; then
      FEED_INPUT_7Z_FULL_FILE="$FEED_INPUT_FULL_FILE.7z"
      FEED_INPUT_7Z_FILE="${FEED_INPUT_7Z_FULL_FILE##*/}"
      if [ -f "$FEED_INPUT_FULL_FILE" ] ; then
         7z a -bd -mx9 "$FEED_INPUT_7Z_FULL_FILE" "$FEED_INPUT_FULL_FILE" > \
            $EZ_DEV_NULL
         SEVENZ_EXIT=$?
         if [ $SEVENZ_EXIT -eq 0 ] ; then
            rm -f "$FEED_INPUT_FULL_FILE"
            echo "Successfully compressed to $FEED_INPUT_7Z_FILE."
         else
            echo "ERROR: 7z failed with exit code $SEVENZ_EXIT."
            exit 1
         fi
      fi
   fi
   let TOTAL_FILES_PARSED=TOTAL_FILES_PARSED+1
   return 0
}

function VerifySingleFeed
{
   let TOTAL_FEEDS=TOTAL_FEEDS+1
   FILE_COUNT=0
   echo
   echo "Successfully verifying feed $FEED_NAME and dir $FEED_STABLE_DIR."
   cd "$FEED_INPUT_FULL_DIR"
   FILE_NAME_LIST=`ls -1 $FILE_NAME_FILTER 2>&1 | \
                   grep -v 'No such file or directory'`
   if [ "$FILE_LIMIT" != 99999 ] ; then
      ONE_FILE_NAME=`echo "$FILE_NAME_LIST" | grep '.0001.7z' | head -1`
      FILE_NAME_LIST=`echo "$FILE_NAME_LIST" | egrep -v '.0001.7z'`
      FILE_NAME_LIST="$ONE_FILE_NAME $FILE_NAME_LIST"
   fi
   if [ "$RANDOM_ORDER" = TRUE ] ; then
      ORIG_FILE_COUNT=`echo "$FILE_NAME_LIST" | wc -l`
      RANDOM_FILE_LIMIT="$FILE_LIMIT"
      if [ $RANDOM_FILE_LIMIT -gt $ORIG_FILE_COUNT ] ; then
         RANDOM_FILE_LIMIT="$ORIG_FILE_COUNT"
      fi
      RANDOM_LOOP_INDEX=0
      RANDOM_FILE_LIST=
      if [ "$RANDOM_INCLUDES_0001" = TRUE ] ; then
         RANDOM_FILE_NAME=`echo "$FILE_NAME_LIST" | grep '.0001.7z' | head -1`
         RANDOM_FILE_LIST="$RANDOM_FILE_LIST $RANDOM_FILE_NAME"
         let RANDOM_LOOP_INDEX=RANDOM_LOOP_INDEX+1
      fi
      while [ $RANDOM_LOOP_INDEX -lt $RANDOM_FILE_LIMIT ]
      do
         let RANDOM_FILE_INDEX=$RANDOM*$ORIG_FILE_COUNT/32768+1
         RANDOM_FILE_NAME=`echo "$FILE_NAME_LIST" | \
                           head -$RANDOM_FILE_INDEX | tail -1`
         RANDOM_FILE_LIST="$RANDOM_FILE_LIST $RANDOM_FILE_NAME"
         let RANDOM_LOOP_INDEX=RANDOM_LOOP_INDEX+1
      done
      FILE_NAME_LIST="$RANDOM_FILE_LIST"
   fi
   for FEED_INPUT_FILE in $FILE_NAME_LIST
   do
      cd "$FEED_INPUT_FULL_DIR"
      FEED_INPUT_FULL_FILE="$FEED_INPUT_FULL_DIR/$FEED_INPUT_FILE"
      FEED_FILE_BASE="$FEED_INPUT_FILE"
      FEED_FILE_BASE="${FEED_FILE_BASE%.7z}"
      FEED_FILE_BASE="${FEED_FILE_BASE%.bz2}"
      FEED_FILE_BASE="${FEED_FILE_BASE%.bzip2}"
      FEED_FILE_BASE="${FEED_FILE_BASE%.gz}"
      FEED_FILE_BASE="${FEED_FILE_BASE%.gzip}"
      FEED_FILE_BASE="${FEED_FILE_BASE%.tar}"
      FEED_FILE_BASE="${FEED_FILE_BASE%.xz}"
      FEED_FILE_BASE="${FEED_FILE_BASE%.zip}"
      FEED_STABLE_FULL_FILE=`echo $FEED_STABLE_FULL_DIR/*$FEED_FILE_BASE*.txt`
      if [ ! -f "$FEED_STABLE_FULL_FILE" ] ; then
         if [ "$CREATE_MODE" = FALSE ] ; then
            echo "ERROR: Failed to find stable file $FEED_STABLE_FULL_FILE."
            EXIT_CODE=1
            return 1
         else
            NEW_IN_FILE_ID=`date '+%s'`
            FEED_STABLE_FILE="$FEED_FILE_BASE.$NEW_IN_FILE_ID.txt"
            FEED_STABLE_FULL_FILE="$FEED_STABLE_FULL_DIR/$FEED_STABLE_FILE"
         fi
      fi
   
      let FILE_COUNT=FILE_COUNT+1
      if [ $FILE_COUNT -gt $FILE_LIMIT ] ; then
         echo -n "Successfully skipping remaining files due to \c"
         echo    "file limit $FILE_LIMIT." 
         return 0
      fi
      VerifySingleFile
      if [ $? -ne 0 -a "$STOP_FILES_ON_ERROR" = TRUE ] ; then
         return 1
      fi
   done
   return 0
}

for ROOT_FILE_OR_DIR in `ls -d $FEED_NAME_FILTER 2>&1 | \
                               grep -v 'No such file or directory'`
do
   cd "$ROOT_DIRECTORY"
   if [ -d "$ROOT_FILE_OR_DIR" ] ; then
      FEED_NAME="$ROOT_FILE_OR_DIR"
      FEED_ROOT_FULL_DIR="$ROOT_DIRECTORY/$FEED_NAME"
      FEED_TEMP_FULL_DIR="$FEED_ROOT_FULL_DIR/Temp"
      FEED_INPUT_FULL_DIR="$FEED_ROOT_FULL_DIR/$INPUT_DIR_NAME"
      if [ ! -d "$FEED_INPUT_FULL_DIR" ] ; then
         echo "ERROR: Failed to find feed input directory $FEED_INPUT_FULL_DIR."
         EXIT_CODE=1
         continue
      fi
      FOUND_STABLE_DIRS=FALSE
      cd "$FEED_ROOT_FULL_DIR"
      PerformSpuriousFileCleanup
      for FEED_STABLE_DIR in `ls -d $STABLE_NAME_FILTER 2>&1 | \
                              grep -v 'No such file or directory'`
      do
         FEED_STABLE_FULL_DIR="$FEED_ROOT_FULL_DIR/$FEED_STABLE_DIR"
         if [ -d "$FEED_STABLE_FULL_DIR" ] ; then
            FOUND_STABLE_DIRS=TRUE
            VerifySingleFeed
            if [ $? -ne 0 -a "$STOP_FEEDS_ON_ERROR" = TRUE ] ; then
               return 1
            fi
         fi
      done
      
      if [ "$FOUND_STABLE_DIRS" = FALSE ] ; then
         echo -n "ERROR: Failed to find any Stable directories for feed \c"
         echo    "$FEED_NAME in directory $FEED_ROOT_FULL_DIR."
         continue
         EXIT_CODE=1
      fi
      if [ $EXIT_CODE -eq 0 ] ; then
         rm -rf "$FEED_TEMP_FULL_DIR"
      fi
   fi
done

if [ "$EXIT_CODE" = 0 ] ; then
   echo -n "Successfully passed parsed $TOTAL_FILES_PARSED files in "
   echo    "$TOTAL_FEEDS feeds."
fi
exit $EXIT_CODE
