#===========================================================================
#  Filename: delete_lines.ksh
#    Author: Craig Schneider
# Orig Date: 01/25/06
# Copyright: ShadowScape Technologies, Inc. (see copyright file for details)
#  Synopsis: Create output file from input file with line deletions.
#===========================================================================

#===========================================================================
# Display the usage.
#===========================================================================
function Usage
{
   if [ "$1" != "" ] ; then
      echo
      echo $*
   fi
   cat <<!

Usage: delete_lines -input InputFileName -output OutputFileName
                    -m MatchString

      -input: The name of the input file to use.
          -m: Match string to be searched for lines to be deleted.
     -output: The name of the output file to be created.
 
!
   exit 1
}

INPUT_FILE_NAME=
MATCH_STRING=
OUTPUT_FILE_NAME=

while [ $# -ne 0 ]
do
   case $1 in
  -i|-input) INPUT_FILE_NAME="$2"
             shift
             shift ;;
         -m) MATCH_STRING="$2"
             shift
             shift ;;
 -o|-output) OUTPUT_FILE_NAME="$2"
             shift
             shift ;;
          *) if [ "$1" != "-?" ] ; then
                Usage "Invalid argument: $1"
             else
                Usage
             fi ;; 
    esac
done

if [ "$INPUT_FILE_NAME" = "" -o "$OUTPUT_FILE_NAME" = "" -o \
     "$MATCH_STRING" = "" ] ; then
   Usage
fi

sed "/$MATCH_STRING/d" "$INPUT_FILE_NAME" > "$OUTPUT_FILE_NAME"
exit 0
