#===========================================================================
#  Filename: desc.ksh
#    Author: Craig Schneider
# Orig Date: 02/18/09
# Copyright: ShadowScape Technologies, Inc. (see copyright file for details)
#  Synopsis: Invoke 4db to describe a database table.
#===========================================================================

TABLE_NAME=
C4DB_OPTS="-set Feedback false"
OUTPUT_MODE=DEFAULT
VERBOSE_MODE=FALSE

function Usage
{
   if [ "$1" != "" ] ; then
      echo
      echo "$1"
   fi
   cat <<!

Usage: desc [-s ServerName] [-d Database] [-create] [-csv | -csvnl | -psv]
            [-json] [-verbose] TableName

   -create) Describe the table as a create table statement.
      -csv) Describe the table as a comma separated list of column names.
    -csvnl) Describe the table as a comma newline list of column names.
        -d) Database name to use within the database server.
     -json) Describe the table by json serializing a DBTableDetails instance.
      -psv) Describe the table as a pipe separated list of column names.
        -s) ServerName of the database server to connect to.
 TableName) The name of the table or view to describe.
  -verbose) Display the verbose output messages.

!
   exit 1
}

typeset -l LOWERCASE_ARG
while [ "$#" -ne 0 ]
do
   LOWERCASE_ARG="$1"
   case $LOWERCASE_ARG in
  -create) OUTPUT_MODE=CREATE
           shift ;;
     -csv) OUTPUT_MODE=CSV
           shift ;;
   -csvnl) OUTPUT_MODE=CSVNL
           shift ;;
       -d) C4DB_OPTS="$C4DB_OPTS -d $2"
           shift
           shift ;;
    -json) OUTPUT_MODE=JSON
           shift ;;
     -psv) OUTPUT_MODE=PSV
           shift ;;
       -s) C4DB_OPTS="$C4DB_OPTS -s $2"
           shift
           shift ;;
 -verbose) VERBOSE_MODE=TRUE
           shift ;;
       -?) Usage
           shift ;;
       *)  if [ "$TABLE_NAME" = "" ] ; then
              TABLE_NAME="$1"
           fi
           shift ;;
   esac
done

if [ "$TABLE_NAME" = "" ] ; then
   Usage "Must specify -t TableName."
fi

if [ "$OUTPUT_MODE" = CREATE ] ; then
   C4DB_CMD="4DB.DescribeAsCreate('$TABLE_NAME')"
elif [ "$OUTPUT_MODE" = CSV ] ; then
   C4DB_CMD="4DB.String ColumnList = GetColumnList('$TABLE_NAME');
4DB.Strings.ColumnList = ColumnList.Replace(' ', '');
4DB.WriteLine(ColumnList);"
elif [ "$OUTPUT_MODE" = CSVNL ] ; then
   C4DB_CMD="4DB.String ColumnList = GetColumnListNL('$TABLE_NAME');
4DB.Strings.ColumnList = ColumnList.Replace(' ', '');
4DB.WriteLine(ColumnList);"
elif [ "$OUTPUT_MODE" = JSON ] ; then
   C4DB_CMD="4DB.DescribeAsJson('$TABLE_NAME')"
elif [ "$OUTPUT_MODE" = PSV ] ; then
   C4DB_CMD="4DB.String ColumnList = GetColumnList('$TABLE_NAME');
4DB.Strings.ColumnList = ColumnList.Replace(' ', '');
4DB.Strings.ColumnList = ColumnList.Replace(',', '|');
4DB.WriteLine(ColumnList);"
else
   C4DB_CMD="desc $TABLE_NAME"
fi

if [ "$VERBOSE_MODE" = TRUE ] ; then
   echo "C4DB $C4DB_OPTS -c \"$C4DB_CMD\""
fi
C4DB $C4DB_OPTS -c "$C4DB_CMD"
exit $?
