#===========================================================================
# FileName: <<FileName>>
#   Author: Craig Schneider
#  Created: 2004-01-18
# Synopsis: Convert line terminators from Dos and Unix.
# <<Copyright>>
#===========================================================================

if [ "$1" = -? ] ; then
   cat <<!

Usage: $0 [-reverse] FileName [OutputFileName]

!
   exit 1
fi

ED_OPTIONS="-sT"

MODE=forward
MODIFY_COMMAND=
if [ "$1" = -modify ] ; then
   MODIFY_COMMAND="$2"
   shift
   shift
fi

if [ "$1" = "-reverse" ] ; then
   MODE=reverse
   ED_OPTIONS="-s"
   shift
fi
if [ "$1" = "-r" ] ; then
   MODE=reverse
   ED_OPTIONS="-s"
   shift
fi

if [ $# -eq 1 ] ; then
   INPUT_FILE_NAME="$1"
   OUTPUT_FILE_NAME="$1"
elif [ $# -eq 2 ] ; then
   INPUT_FILE_NAME="$1"
   OUTPUT_FILE_NAME="$2"
else
   echo "Usage: $0 [-reverse] FileName [OutputFileName]"
   exit 1
fi

if [ "$MODE" = forward ] ; then
   if [ "$MODIFY_COMMAND" != "" ] ; then
      eval $MODIFY_COMMAND $INPUT_FILE_NAME > $OUTPUT_FILE_NAME.tmp
      INPUT_FILE_NAME="$OUTPUT_FILE_NAME.tmp"
   fi
fi

if [ "$EZ_OS_TYPE" = solaris ] ; then
   sed 's/
$//' $INPUT_FILE_NAME > $OUTPUT_FILE_NAME.sed
   mv $OUTPUT_FILE_NAME.sed $OUTPUT_FILE_NAME
elif [ "$EZ_KSH_BASE" = CYGWIN ] ; then
   # Cygwin 1.7.9  displays: in Unix format ... or in DOS format ...
   # Cygwin 1.7.30 displays: in Unix format...  or in DOS format...
   if [ "$MODE" = reverse ] ; then
      unix2dos -n $INPUT_FILE_NAME $OUTPUT_FILE_NAME 2>&1 | \
               egrep -v "in DOS format"
   else
      dos2unix -n $INPUT_FILE_NAME $OUTPUT_FILE_NAME 2>&1 | \
               egrep -v "in Unix format"
   fi
else
   ed $ED_OPTIONS "$INPUT_FILE_NAME" <<!
w $OUTPUT_FILE_NAME
q
!
fi

if [ "$MODE" = reverse ] ; then
   if [ "$MODIFY_COMMAND" != "" ] ; then
      eval $MODIFY_COMMAND $OUTPUT_FILE_NAME > $OUTPUT_FILE_NAME.tmp
      mv $OUTPUT_FILE_NAME.tmp $OUTPUT_FILE_NAME
   fi
fi

exit 0
