#===========================================================================
#  Filename: fam_7z.ksh
#    Author: Craig Schneider
# Orig Date: 04/03/17
# Copyright: ShadowScape Technologies, Inc. (see copyright file for details)
#  Synopsis: Create 7z files for each family.
#===========================================================================

. $EZ_SHARED_ENV

if [ "$1" = -? ] ; then
   cat <<!

Usage: fam 7z

!
   exit 1
fi

for ROOT_DIR in $EZ_FAM_ROOTS
do
   if [ -d "$ROOT_DIR" ] ; then
      cd "$ROOT_DIR"
      FAM_BASE_DIR="${ROOT_DIR##*/}"
      cd ..
      FAMILY_7Z_FILE="$FAM_BASE_DIR.7z"
      rm -f $FAMILY_7Z_FILE
      7z a -bd -mx9 $FAMILY_7Z_FILE $FAM_BASE_DIR
   else
      echo "ERROR: Failed to find family root directory $ROOT_DIR."
      exit 1
   fi
done
exit 0
