#===========================================================================
#  Filename: fam_unsubscribe.ksh
#    Author: Craig Schneider
# Orig Date: 07/10/13
# Copyright: ShadowScape Technologies, Inc. (see copyright file for details)
#  Synopsis: Unsubscribe this computer from a source control family.
#===========================================================================

#===========================================================================
# Display the usage.
#===========================================================================
function Usage
{
   if [ "$1" != "" ] ; then
      echo
      echo $*
   fi
   cat <<!

Usage: fam unsubscribe [-dryrun] [-family FamilyName] [-host HostName]
                     [-quiet | -verbose]

     -dryrun: Display the commands to be executed, without executing them.
     -family: Specifies the name of the source control family to subscribe.
       -host: Specifies the name of the host to unsubscribe.
      -quiet: Suppress non critical messages about operations being performed.
    -verbose: Display verbose messages about operations being performed.

!
   exit 1
}

#===========================================================================
# Process the command line arguments.
#===========================================================================
if [ "$1" = -? ] ; then
   Usage
fi

SUBSCRIBE_ARGS="-unsubscribe"

typeset -l LOWERCASE_ARG
while [ $# -ne 0 ]
do
   LOWERCASE_ARG="$1"
   case $LOWERCASE_ARG in
     -dryrun) SUBSCRIBE_ARGS="$SUBSCRIBE_ARGS $1"
              shift ;;
     -family) SUBSCRIBE_ARGS="$SUBSCRIBE_ARGS $1 $2"
              shift
              shift ;;
       -host) SUBSCRIBE_ARGS="$SUBSCRIBE_ARGS $1 $2"
              shift
              shift ;;
-quiet|-verbose)
              SUBSCRIBE_ARGS="$SUBSCRIBE_ARGS $1"
              shift ;;
           *) if [ "$1" != "-?" ] ; then
                 Usage "Invalid argument: $1"
              else
                 Usage
              fi ;;
    esac
done

fam.sh subscribe -unsubscribe $SUBSCRIBE_ARGS
exit $?
