#===========================================================================
#  Filename: rel_3rd_purge.ksh
#    Author: Craig Schneider
# Orig Date: 01/03/13
# Copyright: ShadowScape Technologies, Inc. (see copyright file for details)
#  Synopsis: Cleanup 3rd party directories that have no references.
#===========================================================================

. $EZ_SHARED_ENV

function Usage
{
   if [ "$1" != "" ] ; then
      echo
      echo "$1"
   fi
   cat <<!

Usage: 3rd_purge [-DryRun] [ -Quiet | -Verbose]

     -DryRun: Display the commands to be executed, without executing them.
      -Quiet: Suppress non critical messages about operations being performed.
    -Verbose: Display verbose messages about operations being performed.

!
   exit 1
}

#===========================================================================
# Process the command line arguments.
#===========================================================================
EZ_DRYRUN=FALSE
EZ_VERBOSITY=

typeset -l LOWERCASE_ARG
while [ $# -ne 0 ]
do
   LOWERCASE_ARG="$1"
   case $LOWERCASE_ARG in
       -dryrun) EZ_DRYRUN="TRUE"
                shift ;;
      -quiet|-verbose)
          EZ_VERBOSITY="${LOWERCASE_ARG#-}"
          shift ;;
            -?) Usage ;;
    esac
done        

EZ_3RD_DIR="$EZ_SUPER_DRIVE/3rdParty"

if [ ! -d "$EZ_3RD_DIR" ] ; then
   echo "ERROR: Failed to find 3rd Party directory $EZ_3RD_DIR."
   exit 1
fi

CFOUR_DIR_LIST=`echo $EZ_3RD_DIR/CFour_*`
for CFOUR_DIR_FULL_NAME in $CFOUR_DIR_LIST
do
   CFOUR_DIR_NAME="${CFOUR_DIR_FULL_NAME##*/}"
   DIR_IS_REFERENCED=FALSE
   REF_QUIET_ARGS=""
   if [ "$EZ_VERBOSITY" != "" ] ; then
      REF_QUIET_ARGS="-$EZ_VERBOSITY"
   fi
   rel.sh 3rd_ref -Status -OnlyRefMessages -d $CFOUR_DIR_NAME $REF_QUIET_ARGS
   if [ $? -eq 1 ] ; then
      DIR_IS_REFERENCED=TRUE
   fi

   if [ "$DIR_IS_REFERENCED" = FALSE ] ; then
      # Ensure the directory is at least 3 days old.
      FIND_RESULT=`find $CFOUR_DIR_FULL_NAME -maxdepth 0 -ctime +3 -print`
      if [ "$FIND_RESULT" != "$CFOUR_DIR_FULL_NAME" ] ; then
         echo "Successfully determined $CFOUR_DIR_NAME \c"
         echo "is not old enough to be purged."
      else
         if [ "$EZ_DRYRUN" = TRUE ] ; then
            echo "Would: Purge unreferenced directory $CFOUR_DIR_FULL_NAME."
         else
            rm -rf "$CFOUR_DIR_FULL_NAME"
            if [ "$EZ_VERBOSITY" != quiet ] ; then
               echo "Successfully purged directory $CFOUR_DIR_FULL_NAME."
            fi
         fi
      fi
   fi
done
exit 0
