#===========================================================================
#  Filename: rel_nuke.ksh
#    Author: Craig Schneider
# Orig Date: 09/07/06
# Copyright: ShadowScape Technologies, Inc. (see copyright file for details)
#  Synopsis: Destroy unreferenced versions of release builds.
#===========================================================================

. $EZ_RELMGR_ENV

if [ "$1" = -? ] ; then
   echo
   echo "Usage: nuke"
   echo
   exit 1
fi

REMOTE_REL_NUKE_HOST=""
if [ "$REL_NUKE_HOSTS" != "" ] ; then
   IS_REL_NUKE_HOST=FALSE
   for SINGLE_HOST in $REL_NUKE_HOSTS
   do
      if [ "$REMOTE_REL_NUKE_HOST" = "" ] ; then
         REMOTE_REL_NUKE_HOST="$SINGLE_HOST"
      fi
      if [ "$EZ_COMPUTERNAME" = "$SINGLE_HOST" ] ; then
         IS_REL_NUKE_HOST=TRUE
      fi
   done
else
   IS_REL_NUKE_HOST=TRUE
fi

if [ "$IS_REL_NUKE_HOST" != TRUE ] ; then
   echo "Successfully starting rel nuke on $REMOTE_REL_NUKE_HOST."
   RemoteRun.ksh -h $REMOTE_REL_NUKE_HOST rel.sh nuke
   echo
   echo
   echo -n "*********** Press enter to exit rel.sh nuke. "
   read answer
   exit 0
fi

RELEASE_INFO_DIR="$EZ_FAMILYTREE_ROOT/Releases/Built"
if [ ! -d "$RELEASE_INFO_DIR" ] ; then
   echo "ERROR: Release info directory $RELEASE_INFO_DIR not found!"
   exit 1
fi
cd "$RELEASE_INFO_DIR"

REL_NUKE_NAME_LIST=`EZRelNukeNameList`
if [ "$REL_NUKE_NAME_LIST" = "" ] ; then
   echo "ERROR: Failed to determine the REL_NUKE_NAME_LIST."
   exit 1
fi

for RELEASE_NAME in $REL_NUKE_NAME_LIST
do
   echo
   echo "Successsfully checking for $RELEASE_NAME releases to destroy."
   echo
   for REL_NAME in `rel.sh select -list -prefix "${RELEASE_NAME}_" | \
                       grep UNREFERENCED | cut -f 1 -d " "`
   do
      if [ "$REL_NAME" != "${RELEASE_NAME}_*" ] ; then
         rel.sh destroy $REL_NAME
      fi
   done 
done

rel.sh list
exit 0
