#===========================================================================
#  Filename: rel_reference.ksh
#    Author: Craig Schneider
# Orig Date: 03/04/02
# Copyright: ShadowScape Technologies, Inc. (see copyright file for details)
#  Synopsis: Add/remove the logical reference from a release.
#===========================================================================

. $EZ_SHARED_ENV

function Usage
{
   if [ "$1" != "" ] ; then
      echo
      echo "$1"
   fi
   echo
   echo "Usage: reference {-a(ADD) | -d(DELETE)} [-l LOGICAL_REFERENCE] [RELEASE_NAME]"
   echo 
   exit 1
}

if [ "$1" = "-?" ] ; then
   Usage
fi

#
# verify first arg is either a or d
#
if [ "$1" != "-a" -a "$1" != "-d" ]; then
   Usage "Incorrect first argument."
fi

#
# parse the args
#
while [ $# -ne 0 ]
do
   case $1 in
     -a) ACTION="add"
         shift
         ;;
     -d) ACTION="delete"
         shift 
         ;;
     -l) REL_REFERENCE="$2"
         shift
         shift
         ;;
     -r) THE_RELEASE=$2
         shift
         shift
         ;;
     -?) Usage
         ;;
      *) THE_RELEASE=$1
         shift
         ;;
    esac
done        

RELEASE_INFO_DIR=$EZ_FAMILYTREE_ROOT/Releases/Built
if [ ! -d "$RELEASE_INFO_DIR" ] ; then
   echo "ERROR: Release info directory $RELEASE_INFO_DIR not found!"
   exit 1
fi

#
# determine the release 
#
if [ "$THE_RELEASE" = "" ] ; then
   rel_pick -a $THE_RELEASE
   if [ "$THE_RELEASE" = "" ] ; then
      echo "ERROR: Failed To Select A Release, Quitting!"
      exit 1
   fi
fi
RELEASE_INFO_FILE=$THE_RELEASE.ksh
echo

cd $RELEASE_INFO_DIR
if [ ! -f $RELEASE_INFO_FILE ] ; then
   echo "ERROR: Failed to find the release file, Quitting!"
   exit 1  
fi

TMP_REL_INFO="$TMPDIR/rel_info.$$"
egrep "LOGICAL_REFERENCE=" $RELEASE_INFO_FILE > "$TMP_REL_INFO"
. "$TMP_REL_INFO"

# prompt for the reference if it is not already there
if [ "$REL_REFERENCE" = "" -a $ACTION = "add" ] ; then
   echo    "Current logical reference: $LOGICAL_REFERENCE"
   echo -n "What is the new reference: "
   read REL_REFERENCE
fi

#
# checkout the file out of source for modification
#
src get $RELEASE_INFO_FILE

#
# remove any existing reference that is there and remove any last rel ref.
#
FIX_REL_INFO="$TMPDIR/rel_info_fix.$$"
cat $RELEASE_INFO_FILE | sed -e '/LOGICAL_REFERENCE=/d' \
    -e '/LAST_RELEASE_REFERENCE=/d' > "$FIX_REL_INFO"
mv "$FIX_REL_INFO" "$RELEASE_INFO_FILE"

if [ ${ACTION} = "add" ] ; then
   echo "LOGICAL_REFERENCE='${REL_REFERENCE}'" >> $RELEASE_INFO_FILE
fi

src put $RELEASE_INFO_FILE

rm -f "$TMP_REL_INFO" "$FIX_REL_INFO"
