#===========================================================================
#  Filename: replace.ksh
#    Author: Craig Schneider
# Orig Date: 01/18/06
# Copyright: ShadowScape Technologies, Inc. (see copyright file for details)
#  Synopsis: Create output file from input file with text replacement.
#===========================================================================

#===========================================================================
# Display the usage.
#===========================================================================
function Usage
{
   if [ "$1" != "" ] ; then
      echo
      echo $*
   fi
   cat <<!

Usage: replace -input InputFileName -output OutputFileName
               -m MatchString -r ReplaceString [-brace] [-verbose]

      -brace: Perform the sed using { instead of / to delimit patterns.
      -input: The name of the input file to use.
          -m: Match string to be searched for and replaced.
     -output: The name of the output file to be created.
          -r: Replacement string to put in place of the match string.
    -verbose: Display verbose messages about operations being performed.
 
!
   exit 1
}

EZ_VERBOSITY=
USE_BRACE=FALSE
INPUT_FILE_NAME=
MATCH_STRING=
OUTPUT_FILE_NAME=
REPLACE_STRING=
REPLACE_STRING_ASSIGNED=FALSE

while [ $# -ne 0 ]
do
   case $1 in
     -brace) USE_BRACE=TRUE
             shift ;;
  -i|-input) INPUT_FILE_NAME="$2"
             shift
             shift ;;
         -m) MATCH_STRING="$2"
             shift
             shift ;;
 -o|-output) OUTPUT_FILE_NAME="$2"
             shift
             shift ;;
         -r) REPLACE_STRING="$2"
             REPLACE_STRING_ASSIGNED=TRUE # replace string can be blank
             shift
             shift ;;
   -verbose) EZ_VERBOSITY="verbose"
             shift ;;
          *) if [ "$1" != "-?" ] ; then
                Usage "Invalid argument: $1"
             else
                Usage
             fi ;; 
    esac
done

if [ "$INPUT_FILE_NAME" = "" -o "$OUTPUT_FILE_NAME" = "" -o \
     "$MATCH_STRING" = "" -o "$REPLACE_STRING_ASSIGNED" = FALSE ] ; then
   Usage
fi

if [ "$EZ_VERBOSITY" = "verbose" ] ; then
   echo -n "Successfully replacing $MATCH_STRING with $REPLACE_STRING in "
   echo    "$INPUT_FILE_NAME into $OUTPUT_FILE_NAME."
fi

if [ "$USE_BRACE" = TRUE ] ; then
   sed "s{$MATCH_STRING{$REPLACE_STRING{g" "$INPUT_FILE_NAME" \
        > "$OUTPUT_FILE_NAME"
else
   sed "s/$MATCH_STRING/$REPLACE_STRING/g" "$INPUT_FILE_NAME" \
        > "$OUTPUT_FILE_NAME"
fi
exit 0
