#===========================================================================
#  Filename: settings_common.ksh
#    Author: Craig Schneider
# Orig Date: 08/13/04
# Copyright: ShadowScape Technologies, Inc. (see copyright file for details)
#  Synopsis: Source control settings for use with any source control system.
#===========================================================================

SRC_OUTPUT="$TMPDIR/src.$$"
if [ "$SRC_REFRESH_DOTTING" != TRUE ] ; then
   . $EZ_SHARED_ENV   # Not when dotting src_refresh since already done.
   rm -f $SRC_OUTPUT  # Not when dotting src_refresh since rm not in path yet.
fi

if [ "$EZ_SVN_CLIENT_ROOT" != "" ] ; then
   export SOURCE_CONTROL_SYSTEM=svn
fi
if [ "$EZ_VSS_ROOT" != "" ] ; then
   export SOURCE_CONTROL_SYSTEM=vss
fi
if [ "$SOURCE_CONTROL_SYSTEM" = "" ] ; then
   echo "WARNING: Unknown source control provider."
   echo "         Must specify SOURCE_CONTROL_SYSTEM."
   return 1
fi

#===========================================================================
# Perform any necessary cleanup.
#===========================================================================
function EZSrcCleanup
{
   rm -f $SRC_OUTPUT
}
if [ "$SRC_REFRESH_DOTTING" != TRUE ] ; then
   trap "EZSrcCleanup ; exit 1" 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15
fi

#===========================================================================
# Get the name of the source control family that we are currently under.
#===========================================================================
function EZSrcGetCurrentFamilyName
{
   CURRENT_ROOT=`EZGetCurrentFamilyRoot`
   echo "${CURRENT_ROOT##*/}"
}

#===========================================================================
# Get the src object text, with object name and type (file/directory).
#===========================================================================
function EZSrcObjectText
{
   SRC_OBJECT="$*"
   if [ -d "$SRC_OBJECT" ] ; then
      if [ "$SRC_OBJECT" = . ] ; then
         echo "directory ${PWD##*/}"
      elif [ "$SRC_OBJECT" = .. ] ; then
         PARENT_DIR="${PWD%/*}"
         echo "directory ${PARENT_DIR##*/}"
      else
         echo "directory $SRC_OBJECT"
      fi
   else
      echo "file $SRC_OBJECT"
   fi
}

#===========================================================================
# If EZSrcMappedFileNameSetup populated SRC_MAPPED_DIR_NAME_RESTORE,
# change back to that directory.
#===========================================================================
function EZSrcMappedDirNameRestore
{
   if [ -d "$SRC_MAPPED_DIR_NAME_RESTORE" ] ; then
      cd "$SRC_MAPPED_DIR_NAME_RESTORE"
   fi
   unset SRC_MAPPED_DIR_NAME_RESTORE
}

#===========================================================================
# Setup the SRC_MAPPED_FILE_NAME variable.  This is the default
# implementation, just echo the file name.
#===========================================================================
function EZSrcMappedFileNameSetup
{
   SRC_MAPPED_FILE_NAME="$1"
}

SRC_SETTINGS_FILE="$(EZGetSrcScriptsDir)/settings_$SOURCE_CONTROL_SYSTEM.ksh"
if [ ! -f "$SRC_SETTINGS_FILE" ] ; then
   echo "ERROR: Failed to find source settings file: $SRC_SETTINGS_FILE."
   exit 1
fi
. $SRC_SETTINGS_FILE
