#===========================================================================
#  Filename: settings_svn.ksh
#    Author: Craig Schneider
# Orig Date: 12/29/10
# Copyright: ShadowScape Technologies, Inc. (see copyright file for details)
#  Synopsis: Common source control settings for use with subversion.
#===========================================================================

#export SRC_CHANGE_PROJECT_COMMAND="ss CP $EZ_SVN_OPTIONS"
export SRC_COMMIT_COMMAND="svn commit $EZ_SVN_OPTIONS"
#export SRC_CREATE_PROJECT_COMMAND="ss Create $EZ_SVN_OPTIONS"
export SRC_CREATE_COMMAND="svn add $EZ_SVN_OPTIONS"
export SRC_DELETE_COMMAND="svn delete $EZ_SVN_OPTIONS"
export SRC_DESTROY_COMMAND="svn delete $EZ_SVN_OPTIONS"
export SRC_EXTRACT_COMMAND="svn update $EZ_SVN_OPTIONS"
export SRC_HISTORY_COMMAND="svn info $EZ_SVN_OPTIONS"
export SRC_GET_COMMAND="svn lock $EZ_SVN_OPTIONS"
#export SRC_HISTORY_COMMAND="ss History $EZ_SVN_OPTIONS"
export SRC_LIST_COMMAND="svn list $EZ_SVN_OPTIONS"
#export SRC_OUT_COMMAND="ss Status $EZ_SVN_OPTIONS"
export SRC_PUT_COMMAND="svn commit $EZ_SVN_OPTIONS"
export SRC_RENAME_COMMAND="svn move $EZ_SVN_OPTIONS"
export SRC_REFRESH_COMMAND="svn update $EZ_SVN_OPTIONS"
export SRC_STATUS_COMMAND="svn status $EZ_SVN_OPTIONS"
export SRC_TEST_COMMAND="svn list $EZ_SVN_OPTIONS"
export SRC_UNGET_COMMAND="svn unlock $EZ_SVN_OPTIONS"

export SRC_MESSAGE_FLAG="--message "

#===========================================================================
# Set the activity to be used for checking out a file/directory.
#===========================================================================
function EZSrcSetCheckoutActivity
{
   REL_MINUS_WORKING="${EZ_ACTIVE_RELEASE%working*}"
   REL_MINUS_SHARED="${EZ_ACTIVE_RELEASE%shared*}"
   if [ "$REL_MINUS_WORKING" != "$EZ_ACTIVE_RELEASE" -a \
        "$REL_MINUS_SHARED"  != "$EZ_ACTIVE_RELEASE" ] ; then
      echo -n "You are setup for $EZ_ACTIVE_RELEASE, checkout anyway <y,n>? "
      read ANSWER
      if [ "$ANSWER" != Y -a "$ANSWER" != y ] ; then
         echo "Checkout operation aborted by user."
         exit 1
      fi
   fi
   return 0
}

#===========================================================================
# Get the file name as mapped in source control.
#===========================================================================
function EZSrcGetRepositoryRevision
{
   REPOSITORY_REVISION=`svn info $EZ_SOURCE_CONTROL_ROOT | tr -d '\r' | \
                        grep 'Revision:' | awk '{print $2}' `
   echo "$REPOSITORY_REVISION"
}

#===========================================================================
# Get the file name as mapped in source control.
#===========================================================================
function EZSrcGetProjectDirectory
{
   CURRENT_ROOT=`EZGetCurrentFamilyRoot`
   SRC_FAMILY_NAME="${CURRENT_ROOT##*/}"
   WIN_PWD="$(EZPath2Win $PWD)"
   FAM_RELATIVE_PATH="${WIN_PWD#$CURRENT_ROOT}"
   echo "$EZ_RELEASE_ROOT/$SRC_FAMILY_NAME${FAM_RELATIVE_PATH}"
}

#===========================================================================
# Get the file root as mapped in source control.
#===========================================================================
function EZSrcGetMappedFamilyRoot
{
   CURRENT_ROOT=`EZGetCurrentFamilyRoot`
   echo "$EZ_RELEASE_ROOT/${CURRENT_ROOT##*/}"
}

#===========================================================================
# Setup the SRC_MAPPED_FILE_NAME and SRC_MAPPED_DIR_NAME_RESTORE variables.
#===========================================================================
function EZSrcMappedFileNameSetup
{
   SRC_BASE_FILE_NAME="$1"
   LOCAL_OR_REMOTE="$2"

   if [ "$LOCAL_OR_REMOTE" != "LOCAL" ] ; then
      UNMAPPED_FILE_DIR="${SRC_BASE_FILE_NAME%/*}"
      # check for relative or full path to file and if exists, cd there.
      if [ "$UNMAPPED_FILE_DIR" != "$SRC_BASE_FILE_NAME" -a \
           -d "$UNMAPPED_FILE_DIR" ] ; then
         SRC_MAPPED_DIR_NAME_RESTORE="$PWD"
         SRC_BASE_FILE_NAME="${SRC_BASE_FILE_NAME#$UNMAPPED_FILE_DIR/}"
         cd "$UNMAPPED_FILE_DIR"
      fi
   fi

   SRC_PROJECT_DIR=`EZSrcGetProjectDirectory`
   SRC_MAPPED_FILE_NAME="$SRC_PROJECT_DIR/$SRC_BASE_FILE_NAME"
   if [ "$LOCAL_OR_REMOTE" = "LOCAL" ] ; then
      SRC_MAPPED_FILE_NAME="$SRC_BASE_FILE_NAME"
   fi
}
