#===========================================================================
#  Filename: settings_vss.ksh
#    Author: Craig Schneider
# Orig Date: 08/13/04
# Copyright: ShadowScape Technologies, Inc. (see copyright file for details)
#  Synopsis: Common source control settings for use with visual source safe.
#===========================================================================

export SRC_CHANGE_PROJECT_COMMAND="ss CP $EZ_VSS_OPTIONS"
export SRC_CREATE_PROJECT_COMMAND="ss Create $EZ_VSS_OPTIONS"
export SRC_CREATE_COMMAND="ss Add -i-N $EZ_VSS_OPTIONS"
export SRC_DELETE_COMMAND="ss Delete -i-Y -S $EZ_VSS_OPTIONS"
export SRC_DESTROY_COMMAND="ss Destroy -i-Y -S $EZ_VSS_OPTIONS"
export SRC_EXTRACT_COMMAND="ss Get $EZ_VSS_OPTIONS"
export SRC_GET_COMMAND="ss Checkout -I- $EZ_VSS_OPTIONS"
export SRC_HISTORY_COMMAND="ss History $EZ_VSS_OPTIONS"
export SRC_OUT_COMMAND="ss Status $EZ_VSS_OPTIONS"
export SRC_PUT_COMMAND="ss Checkin $EZ_VSS_OPTIONS"
export SRC_RENAME_COMMAND="ss Rename -S $EZ_VSS_OPTIONS"
export SRC_REFRESH_COMMAND="ss Get -i-N $EZ_VSS_OPTIONS"
export SRC_TEST_COMMAND="ss Properties $EZ_VSS_OPTIONS"
export SRC_UNGET_COMMAND="ss UndoCheckout -i-Y $EZ_VSS_OPTIONS"

export SRC_MESSAGE_FLAG="-c"

#===========================================================================
# Set the activity to be used for checking out a file/directory.
#===========================================================================
function EZSrcSetCheckoutActivity
{
   REL_MINUS_WORKING="${EZ_ACTIVE_RELEASE%working*}"
   REL_MINUS_SHARED="${EZ_ACTIVE_RELEASE%shared*}"
   if [ "$REL_MINUS_WORKING" != "$EZ_ACTIVE_RELEASE" -a \
        "$REL_MINUS_SHARED"  != "$EZ_ACTIVE_RELEASE" ] ; then
      echo -n "You are setup for $EZ_ACTIVE_RELEASE, checkout anyway <y,n>? "
      read ANSWER
      if [ "$ANSWER" != Y -a "$ANSWER" != y ] ; then
         echo "Checkout operation aborted by user."
         exit 1
      fi
   fi
   return 0
}

#===========================================================================
# Get the file name as mapped in source control.
#===========================================================================
function EZSrcGetProjectDirectory
{
   CURRENT_ROOT=`EZGetCurrentFamilyRoot`
   SRC_FAMILY_NAME="${CURRENT_ROOT##*/}"
   WIN_PWD="$(EZPath2Win $PWD)"
   FAM_RELATIVE_PATH="${WIN_PWD#$CURRENT_ROOT}"
   echo "$EZ_RELEASE_ROOT/$SRC_FAMILY_NAME${FAM_RELATIVE_PATH}"
}

#===========================================================================
# Get the file root as mapped in source control.
#===========================================================================
function EZSrcGetMappedFamilyRoot
{
   CURRENT_ROOT=`EZGetCurrentFamilyRoot`
   echo "$EZ_RELEASE_ROOT/${CURRENT_ROOT##*/}"
}

#===========================================================================
# Setup the SRC_MAPPED_FILE_NAME and SRC_MAPPED_DIR_NAME_RESTORE variables.
#===========================================================================
function EZSrcMappedFileNameSetup
{
   SRC_BASE_FILE_NAME="$1"

   UNMAPPED_FILE_DIR="${SRC_BASE_FILE_NAME%/*}"
   # check for relative or full path to file and if exists, cd there.
   if [ "$UNMAPPED_FILE_DIR" != "$SRC_BASE_FILE_NAME" -a \
        -d "$UNMAPPED_FILE_DIR" ] ; then
      SRC_MAPPED_DIR_NAME_RESTORE="$PWD"
      SRC_BASE_FILE_NAME="${SRC_BASE_FILE_NAME#$UNMAPPED_FILE_DIR/}"
      cd "$UNMAPPED_FILE_DIR"
   fi

   SRC_PROJECT_DIR=`EZSrcGetProjectDirectory`
   SRC_MAPPED_FILE_NAME="$SRC_PROJECT_DIR/$SRC_BASE_FILE_NAME"
}
