#===========================================================================
#  Filename: src_change_list.ksh
#    Author: Craig Schneider
# Orig Date: 06/23/2009
# Copyright: ShadowScape Technologies, Inc. (see copyright file for details)
#  Synopsis: Get the list of changes between to releases.
#===========================================================================

. $EZ_SOURCE_ENV

#===========================================================================
# Display the usage.
#===========================================================================
function Usage
{
   if [ "$1" != "" ] ; then
      echo
      echo $*
   fi
   cat <<!

Usage: src change_list -f FamilyName -s SourceLabel -t TargetLabel [-raw]
                   [-dryrun] [-quiet | -verbose]

     -dryrun: Display the commands to be executed, without executing them.
          -f: Family name to get the change list for.
      -quiet: Suppress non critical messages about operations being performed.
          -s: Source release label (e.g. CFour_3.5.3000).
          -t: Target release label (e.g. CFour_3.5.3001).
    -verbose: Display verbose messages about operations being performed.

!
   exit 1
}

#===========================================================================
# Process the command line arguments.
#===========================================================================

EXIT_CODE=0

FAMILY_NAME=
RAW_FORMAT=FALSE
SOURCE_LABEL=
TARGET_LABEL=
EZ_DRYRUN=FALSE
EZ_VERBOSITY=

typeset -l LOWERCASE_ARG
while [ $# -ne 0 ]
do
   LOWERCASE_ARG="$1"
   case $LOWERCASE_ARG in
      -dryrun)
          EZ_DRYRUN=TRUE
          shift ;;
      -f) FAMILY_NAME="$2"
          shift
          shift ;;
      -quiet|-verbose)
          EZ_VERBOSITY="${LOWERCASE_ARG#-}"
          shift ;;
      -raw)
          RAW_FORMAT=TRUE
          shift ;;
      -s) SOURCE_LABEL="$2"
          shift
          shift ;;
      -t) TARGET_LABEL="$2"
          shift
          shift ;;
      *)  if [ "$1" != "-?" ] ; then
             Usage "Invalid argument: $1"
          else
             Usage
          fi ;;
    esac
done

if [ "$FAMILY_NAME" = "" ] ; then
   Usage "Must specify -f FamilyName."
fi

if [ "$SOURCE_LABEL" = "" ] ; then
   Usage "Must specify -s SourceLabel."
fi

if [ "$TARGET_LABEL" = "" ] ; then
   Usage "Must specify -t TargetLabel."
fi

#===========================================================================
# Perform the requested source control operations.
#===========================================================================

if [ "$SOURCE_CONTROL_SYSTEM" = vss ] ; then
   # -out_err_file $SRC_OUTPUT
   EZInvokeCommand -out_err_file $SRC_OUTPUT $SRC_HISTORY_COMMAND \
          $EZ_RELEASE_ROOT/$FAMILY_NAME -R -vL${TARGET_LABEL}~${SOURCE_LABEL}
   if [ $? -ne 0 ] ; then
      EXIT_CODE=1
   fi
   if [ "$EZ_DRYRUN" != TRUE ] ; then
      if [ "$RAW_FORMAT" = "TRUE" ] ; then
         cat $SRC_OUTPUT
      else
         cat $SRC_OUTPUT
         echo
         echo "Non raw format should do something better with this output."
         echo
      fi
   fi
fi

EZSrcCleanup
exit $EXIT_CODE
