#===========================================================================
#  Filename: src_late_put.ksh
#    Author: Craig Schneider
# Orig Date: 09/09/04
# Copyright: ShadowScape Technologies, Inc. (see copyright file for details)
#  Synopsis: Check the hijacked version of a file into source control.
#===========================================================================

. $EZ_SOURCE_ENV

#===========================================================================
# Display the usage.
#===========================================================================
function Usage
{
   if [ "$1" != "" ] ; then
      echo
      echo $*
   fi
   cat <<!

Usage: src late_put FileName(s)...
                   [-dryrun] [-quiet | -verbose]

     -dryrun: Display the commands to be executed, without executing them.
 FileName(s): One or more hijacked file names to check in to source control.
          -m: The message to be used as the reason for checkin.
      -quiet: Suppress non critical messages about operations being performed.
    -verbose: Display verbose messages about operations being performed.

!
   exit 1
}

#===========================================================================
# Process the command line arguments.
#===========================================================================
if [ "$1" = -? ] ; then
   Usage
fi
if [ $# -eq 0 ] ; then
   Usage
fi

integer SRC_FILE_LIST_COUNT=0
EXIT_CODE=0

EZ_DRYRUN=FALSE
EZ_VERBOSITY=
MESSAGE_TEXT="late put"
SRC_OPTS=

typeset -l LOWERCASE_ARG
while [ $# -ne 0 ]
do
   LOWERCASE_ARG="$1"
   case $LOWERCASE_ARG in
      -dryrun)
          EZ_DRYRUN=TRUE
          shift ;;
      -m) MESSAGE_TEXT="$2"
          shift
          shift ;;
      -quiet|-verbose)
          EZ_VERBOSITY="${LOWERCASE_ARG#-}"
          SRC_OPTS="$SRC_OPTS $1"
          shift ;;
      -*) if [ "$1" != "-?" ] ; then
             Usage "Invalid argument: $1"
          else
             Usage
          fi ;;
       *) SRC_FILE_NAME_LIST[SRC_FILE_LIST_COUNT]="$1"
          SRC_FILE_LIST_COUNT=SRC_FILE_LIST_COUNT+1
          shift ;;
    esac
done

#===========================================================================
# Perform the requested source control operations.
#===========================================================================
integer COUNT=0
while [ $COUNT -lt $SRC_FILE_LIST_COUNT ]
do
   SRC_FILE_NAME="${SRC_FILE_NAME_LIST[COUNT]}"
   COUNT=COUNT+1

   if [ ! -f "$SRC_FILE_NAME" ] ; then
      echo "ERROR: Failed to find file $SRC_FILE_NAME."
      EXIT_CODE=1
      continue
   fi
   EZInvokeCommand mv "$SRC_FILE_NAME" "$SRC_FILE_NAME.late_put"
   if [ $? -ne 0 ] ; then
      echo "ERROR: Failed moving $SRC_FILE_NAME to the side."
      EXIT_CODE=1
      continue
   fi
   EZInvokeCommand src.ksh get $SRC_OPTS "$SRC_FILE_NAME"
   EZInvokeCommand mv "$SRC_FILE_NAME.late_put" "$SRC_FILE_NAME"
   EZInvokeCommand src.ksh put $SRC_OPTS -m "$MESSAGE_TEXT" "$SRC_FILE_NAME"
done

EZSrcCleanup
exit $EXIT_CODE
