#===========================================================================
#  Filename: src_test.ksh
#    Author: Craig Schneider
# Orig Date: 09/01/04
# Copyright: ShadowScape Technologies, Inc. (see copyright file for details)
#  Synopsis: Test if files and/or directories exist in source control.
#===========================================================================

. $EZ_SOURCE_ENV

#===========================================================================
# Display the usage.
#===========================================================================
function Usage
{
   if [ "$1" != "" ] ; then
      echo
      echo $*
   fi
   cat <<!

Usage: src test FileName(s)...
                   [-dryrun] [-quiet | -verbose]

     -dryrun: Display the commands to be executed, without executing them.
 FileName(s): One or more file names to test if exist in source control.
      -quiet: Suppress non critical messages about operations being performed.
    -verbose: Display verbose messages about operations being performed.

!
   exit 1
}

#===========================================================================
# Process the command line arguments.
#===========================================================================
if [ "$1" = -? ] ; then
   Usage
fi
if [ $# -eq 0 ] ; then
   Usage
fi

integer SRC_FILE_LIST_COUNT=0
EXIT_CODE=0

EZ_DRYRUN=FALSE
EZ_VERBOSITY=

typeset -l LOWERCASE_ARG
while [ $# -ne 0 ]
do
   LOWERCASE_ARG="$1"
   case $LOWERCASE_ARG in
      -dryrun)
          EZ_DRYRUN=TRUE
          shift ;;
      -quiet|-verbose)
          EZ_VERBOSITY="${LOWERCASE_ARG#-}"
          shift ;;
      -*) if [ "$1" != "-?" ] ; then
             Usage "Invalid argument: $1"
          else
             Usage
          fi ;;
       *) SRC_FILE_NAME_LIST[SRC_FILE_LIST_COUNT]="$1"
          SRC_FILE_LIST_COUNT=SRC_FILE_LIST_COUNT+1
          shift ;;
    esac
done

#===========================================================================
# Perform the requested source control operations.
#===========================================================================
integer COUNT=0
while [ $COUNT -lt $SRC_FILE_LIST_COUNT ]
do
   SRC_FILE_NAME="${SRC_FILE_NAME_LIST[COUNT]}"
   COUNT=COUNT+1

   EZSrcMappedFileNameSetup "$SRC_FILE_NAME" LOCAL
   if [ "$SOURCE_CONTROL_SYSTEM" = svn -o \
        "$SOURCE_CONTROL_SYSTEM" = vss ] ; then
      EZInvokeCommand -out_err_file $SRC_OUTPUT \
              $SRC_TEST_COMMAND "$SRC_MAPPED_FILE_NAME"
      if [ $? -ne 0 ] ; then # SRC_TEST_COMMAND exits with 100 if missing
         EXIT_CODE=1
      fi
   else
      echo "ERROR: Unsupported source control system $SOURCE_CONTROL_SYSTEM."
      EXIT_CODE=1
   fi
   EZSrcMappedDirNameRestore
done

EZSrcCleanup
exit $EXIT_CODE
