#===========================================================================
#  Filename: src_section.ksh
#    Author: Craig Schneider
# Orig Date: 11/16/96
# Copyright: ShadowScape Technologies, Inc. (see copyright file for details)
#  Synopsis: Find all ShadowScape modifications to source files.
#            A document describing the changes is created.
#===========================================================================

NUMBERING_ON=0
if [ "$1" = "-n" ] ; then
   NUMBERING_ON=1
   shift
fi

# FIX: use options -s -e -r -f
if [ "$1" = -? -o $# -ne 3 ] ; then
   echo
   echo Usage: $0 [-n] STARTING_PATTERN ENDING_PATTERN FILENAME
   echo
   return
fi

STARTING_PATTERN="$1"
ENDING_PATTERN="$2"
FILENAME="$3"
REQUIRED_PATTERN=ShadowScape
REQ_PATTERN_ON=0

cat $FILENAME | awk '
BEGIN { line_number = 0; inside_block = 0; }
{
   line_number = line_number + 1;
   if (index($0, ENDING_PATTERN) != 0 && inside_block == 1) {
      if (REQ_PATTERN_ON  == 1 && index($0, REQUIRED_PATTERN) == 0)
         next;
      if (NUMBERING_ON == 1)
         printf("%04d ", line_number);
      printf("%s\n", $0);
      printf("\n");
      inside_block = 0;
      }
   if (inside_block == 1) {
      if (NUMBERING_ON == 1)
         printf("%04d ", line_number);
      printf("%s\n", $0);
      }
   if (index($0, STARTING_PATTERN) != 0) {
      if (REQ_PATTERN_ON == 1 && index($0, REQUIRED_PATTERN) == 0)
         next;
      inside_block = 1;
      if (NUMBERING_ON == 1) {
         printf("LINE TEXT\n");
         printf("%04d ", line_number);
         }
      printf("%s\n", $0);
      if (index($0, ENDING_PATTERN) != 0) {
         inside_block = 0;
         }
      }
} ' STARTING_PATTERN="$STARTING_PATTERN" \
      ENDING_PATTERN="$ENDING_PATTERN" \
      REQ_PATTERN_ON="$REQ_PATTERN_ON" \
    REQUIRED_PATTERN="$REQUIRED_PATTERN" \
        NUMBERING_ON="$NUMBERING_ON"
