#===========================================================================
#  Filename: zap.ksh
#    Author: Craig Schneider
# Orig Date: 09/24/04
# Copyright: ShadowScape Technologies, Inc. (see copyright file for details)
#  Synopsis: Sends a kill -9 signal to the specified process name.
#===========================================================================

#===========================================================================
# Display the usage.
#===========================================================================
function Usage
{
   if [ "$1" != "" ] ; then
      echo
      echo $*
   fi
   cat <<!

Usage: zap [KillSignal] ProcessName

  KillSignal: kill signal to use in the range -0 ... -15 (default -9).
 ProcessName: The name of the process to be zapped with the signal.

!
   exit 1
}

KILL_SIGNAL=-9
PROCESS_NAME=

while [ $# -ne 0 ]
do
   case $1 in
      -0|-1|-2|-3|-4|-5|-6|-7|-8|-9|-10|-11|-12|-13|-14|-15)
          KILL_SIGNAL=$1
          shift ;;
      -*) if [ "$1" != "-?" ] ; then
             Usage "Invalid argument: $1"
          else
             Usage
          fi ;;
       *) PROCESS_NAME="$1"
          shift ;;
    esac
done

if [ "$PROCESS_NAME" = "" ] ; then
   Usage "Must specify a Process Name to zap."
fi

TMP_FILE="$TMPDIR/zap.$$"
ps -e -o pid,args | egrep -v "grep|zap" | grep "$PROCESS_NAME" > "$TMP_FILE"
while read PID PROCESS_TEXT
do
   kill $KILL_SIGNAL $PID
   if [ $? -eq 0 ] ; then
      echo "Successfully Killed: $PROCESS_TEXT"
   else
      echo "ERROR: Failed Killing: $PROCESS_TEXT"
   fi
done < "$TMP_FILE"
rm -f "$TMP_FILE"

exit 0
